@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.54 2006/02/01 15:30:18 bowkenken Exp $
+* $Id: amenu.c,v 1.57 2006/08/11 00:43:13 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -37,6 +37,11 @@
 
 /***************************************************************/
 
+#define	STR_TTL_AUTO_MARK_SPLIT_NAME	" - "
+#define	STR_TTL_AUTO_MARK_SPLIT_CODE	"\n"
+
+/***************************************************************/
+
 static auto_mark_t	ls_auto_mark[LS_MBR_MAX_N][AUTO_MARK_MAX_N];
 static auto_mark_t	clip_board_large[LS_MBR_MAX_N];
 static auto_mark_t	clip_board_small;
@@ -235,7 +240,7 @@ void	init_auto_menu( void )
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		clip_board_large[i] = ls_auto_mark[i][0];
 
-		strncpy( clip_board_ttl,
+		str_nz_cpy( clip_board_ttl,
 				msg_ttl_auto_mark[0],
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -299,7 +304,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
-		strncpy( msg_ttl_auto_mark[j],
+		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -323,7 +328,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far;
 		break;
 	}
-	strncpy( msg_ttl_auto_mark[j],
+	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 	j++;
@@ -345,7 +350,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far_prio;
 		break;
 	}
-	strncpy( msg_ttl_auto_mark[j],
+	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRIO,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 	j++;
@@ -365,7 +370,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far;
 		break;
 	}
-	strncpy( msg_ttl_auto_mark[j],
+	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 	j++;
@@ -385,7 +390,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far_prio;
 		break;
 	}
-	strncpy( msg_ttl_auto_mark[j],
+	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 	j++;
@@ -394,7 +399,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
-		strncpy( msg_ttl_auto_mark[j],
+		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -404,7 +409,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
-		strncpy( msg_ttl_auto_mark[j],
+		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -416,7 +421,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_all;
-		strncpy( msg_ttl_auto_mark[j],
+		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -426,7 +431,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_own;
-		strncpy( msg_ttl_auto_mark[j],
+		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -434,7 +439,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	j = AUTO_MARK_MAX_N - 1;
 	ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
-	strncpy( msg_ttl_auto_mark[j],
+	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_CLEAR,
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 }
@@ -464,7 +469,7 @@ void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
 
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
-		strncpy( msg_ttl_auto_mark[j],
+		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -481,7 +486,7 @@ void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
 
 	if( j < AUTO_MARK_MAX_N ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
-		strncpy( msg_ttl_auto_mark[j],
+		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -554,6 +559,63 @@ void	ver_up_auto_mark_1_1_1( long ls_mbr_n )
 	init_auto_mark_appoint( ls_mbr_n );
 }
 
+/***************************************************************
+* ΥСʥå
+* long ls_mbr_n : СΥꥹֹ
+***************************************************************/
+
+void	ver_up_auto_mark_1_1_3( void )
+{
+	long	j;
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ )
+		cv_msg_ttl_auto_mark( msg_ttl_auto_mark[j] );
+}
+
+/***************************************************************
+* ȥζڤʸ " - "  "\n" Ѵ
+* char *ttl : ȥ
+***************************************************************/
+
+void	cv_msg_ttl_auto_mark( char *ttl )
+{
+	static char	old_split[] = " - ";
+	char	work_left[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	work_right[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	*p;
+
+	/* ȥ뤫 " - " κ¦Ф */
+
+	str_nz_cpy( work_left, ttl, MSG_TTL_AUTO_MARK_MAX_LEN );
+	p = strstr( work_left, old_split );
+	if( p != NULL )
+		*p = '\0';
+
+	str_trim_tail( work_left, " \t\n" );
+
+	/* ȥ뤫 " - " α¦Ф */
+
+	p = strstr( ttl, old_split );
+	if( p == NULL ){
+		work_right[0] = '\0';
+	} else {
+		long	len;
+
+		len = str_len_std( old_split );
+		str_nz_cpy( work_right, &(p[len]), MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+
+	/* ȥ˽᤹ */
+
+	ttl[0] = '\0';
+	str_max_n_cat( ttl, work_left,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_max_n_cat( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_max_n_cat( ttl, work_right,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+}
+
 /***************************************************************
 * ˥塼
 * menu_t **pp : ˥塼
@@ -579,14 +641,16 @@ char	*menu_auto_mark( menu_t **pp, menu_t **dflt )
 
 void	set_menu_auto_mark( menu_t **dflt )
 {
+	long	left_max_len;
 	menu_t	*p;
+	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 2 + 16 + 1];
 	long	i, k;
 
 	p = ls_menu_auto_mark;
 	k = 0;
 
-	strncpy( p[k].path, "/auto mark", MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( p[k].path, "/auto mark", MENU_PATH_MAX_LEN );
+	str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
@@ -595,17 +659,25 @@ void	set_menu_auto_mark( menu_t **dflt )
 	p[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( p[k].path, "/auto mark/title", MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( p[k].path, "/auto mark/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
-	strncpy( p[k].msg, MSG_TTL_MENU_AUTO_MARK,
+	str_nz_cpy( p[k].msg, MSG_TTL_MENU_AUTO_MARK,
 			MENU_MSG_MAX_LEN );
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
 	k++;
 
+	left_max_len = 1;
+	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
+		long	len;
+
+		len = str_len_draw( get_msg_ttl_auto_mark_info( i ) );
+		left_max_len = max_l( left_max_len, len );
+	}
+
 	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
 		long	kk;
 
@@ -614,22 +686,28 @@ void	set_menu_auto_mark( menu_t **dflt )
 		if( i == auto_mark_cur_n )
 			*dflt = &(p[k]);
 
+		sprintf( buf, "%*s%s%s",
+				(int)left_max_len,
+				get_msg_ttl_auto_mark_info( i ),
+				STR_TTL_AUTO_MARK_SPLIT_NAME,
+
+				get_msg_ttl_auto_mark_hint( i ) );
+
 		sprintf( p[k].path, "/auto mark/%ld", i );
-		strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = (char)('A' + i);
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, get_msg_ttl_auto_mark( i ),
-				MENU_MSG_MAX_LEN );
+		str_nz_cpy( p[k].msg, buf, MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
 		k++;
 
 		sprintf( p[k].path, "%s/exec", p[kk].path );
-		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'X';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_EXEC,
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EXEC,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = cb_menu_auto_mark_exec;
 		p[k].arg = (void *)i;
@@ -637,10 +715,10 @@ void	set_menu_auto_mark( menu_t **dflt )
 		k++;
 
 		sprintf( p[k].path, "%s/edit", p[kk].path );
-		strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'E';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT,
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = cb_menu_auto_mark_edit;
 		p[k].arg = (void *)i;
@@ -648,10 +726,10 @@ void	set_menu_auto_mark( menu_t **dflt )
 		k++;
 
 		sprintf( p[k].path, "%s/copy", p[kk].path );
-		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'W';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_COPY,
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_COPY,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = cb_menu_auto_mark_copy_large;
 		p[k].arg = (void *)i;
@@ -659,23 +737,34 @@ void	set_menu_auto_mark( menu_t **dflt )
 		k++;
 
 		sprintf( p[k].path, "%s/paste", p[kk].path );
-		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'Y';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_PASTE,
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_PASTE,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = cb_menu_auto_mark_paste_large;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( p[k].path, "%s/arrange", p[kk].path );
-		strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
-		p[k].accel_key = 'A';
+		sprintf( p[k].path, "%s/arrange top", p[kk].path );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'T';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE,
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_TOP,
 				MENU_MSG_MAX_LEN );
-		p[k].call_back = cb_menu_auto_mark_arrange;
+		p[k].call_back = cb_menu_auto_mark_arrange_top;
+		p[k].arg = (void *)i;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		sprintf( p[k].path, "%s/arrange bottom", p[kk].path );
+		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'B';
+		p[k].short_key[0] = '\0';
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_BOTTOM,
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_auto_mark_arrange_bottom;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
 		k++;
@@ -1198,7 +1287,7 @@ char	*cb_menu_auto_mark_edit_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_EDIT,
-			get_msg_ttl_auto_mark( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	/* о */
@@ -1276,7 +1365,7 @@ char	*cb_menu_auto_mark_trgt_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_TRGT,
-			get_msg_ttl_auto_mark( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1379,7 +1468,7 @@ char	*cb_menu_auto_mark_dist_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_DIST,
-			get_msg_ttl_auto_mark( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1442,7 +1531,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_ACT,
-			get_msg_ttl_auto_mark( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	s = NULL;
@@ -1592,7 +1681,7 @@ char	*cb_menu_auto_mark_cond_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
-			get_msg_ttl_auto_mark( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	/* ǥեȤΥ */
@@ -1641,7 +1730,7 @@ char	*cb_menu_auto_mark_cond_init(
 	if( p == NULL )
 		return STR_MENU_ERR;
 	sprintf( p->msg, MSG_TTL_MENU_AUTO_MARK_COND,
-			get_msg_ttl_auto_mark( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
 			g_sel_mbr->name );
 
 	return NULL;
@@ -1702,9 +1791,9 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls = ls_menu_appoint_item;
 	k = 0;
 
-	strncpy( ls[k].path, "/appoint item",
+	str_nz_cpy( ls[k].path, "/appoint item",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -1715,15 +1804,15 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/appoint item/title",
+	str_nz_cpy( ls[k].path, "/appoint item/title",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>",
+	str_nz_cpy( ls[k].kind, "<Title>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	sprintf( ls[k].msg, MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
-			get_msg_ttl_auto_mark( auto_mark_cur_n ),
+			get_msg_ttl_auto_mark_name( auto_mark_cur_n ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
@@ -1773,12 +1862,12 @@ char	*set_menu_auto_mark_appoint_item(
 	mjr = (*apo)->mjr;
 
 	sprintf( ls[*k].path, "/appoint item/%c", mjr );
-	strncpy( ls[*k].kind, "<Branch>",
+	str_nz_cpy( ls[*k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = mjr_key;
 	ls[*k].short_key[0] = '\0';
 	ls[*k].n_msg = N_MSG_NULL;
-	strncpy( ls[*k].msg, get_item_mjr_name( mjr ),
+	str_nz_cpy( ls[*k].msg, get_item_mjr_name( mjr ),
 			MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_auto_mark_appoint_item_init;
 	ls[*k].arg = (void *)(*apo);
@@ -1800,12 +1889,12 @@ char	*set_menu_auto_mark_appoint_item(
 
 		sprintf( ls[*k].path, "/appoint item/%c/%c",
 				(*apo)->mjr, (*apo)->mnr );
-		strncpy( ls[*k].kind, "<CheckItem>",
+		str_nz_cpy( ls[*k].kind, "<CheckItem>",
 				MENU_KIND_MAX_LEN );
 		ls[*k].accel_key = mnr_key;
 		ls[*k].short_key[0] = '\0';
 		ls[*k].n_msg = N_MSG_NULL;
-		strncpy( ls[*k].msg, name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[*k].msg, name, MENU_MSG_MAX_LEN );
 		ls[*k].call_back = cb_menu_auto_mark_appoint_item_mnr;
 		ls[*k].arg = (void *)(*apo);
 		ls[*k].flg = FLG_NULL;
@@ -1924,7 +2013,7 @@ char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt )
 
 	/* ޥ */
 
-	strncpy( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro,
+	str_nz_cpy( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro,
 			buf_cmd, MACRO_MAX_LEN );
 
 	return STR_MENU_CANCEL;
@@ -1987,7 +2076,7 @@ char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt )
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		clip_board_large[i] = ls_auto_mark[i][n];
 
-		strncpy( clip_board_ttl,
+		str_nz_cpy( clip_board_ttl,
 				msg_ttl_auto_mark[n],
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -2014,7 +2103,7 @@ char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		ls_auto_mark[i][n] = clip_board_large[i];
 
-		strncpy( msg_ttl_auto_mark[n],
+		str_nz_cpy( msg_ttl_auto_mark[n],
 				clip_board_ttl,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
@@ -2067,47 +2156,113 @@ char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 * return : ˥塼ΰư
 ***************************************************************/
 
-char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt )
+char	*cb_menu_auto_mark_arrange_top( menu_t **pp, menu_t **dflt )
 {
-	long	n, i, j;
+	char	*ret;
+
+	ret = menu_auto_mark_arrange( (long)((*pp)->arg), -1 );
+
+	set_menu_auto_mark( dflt );
+
+	return ret;
+}
+
+/***************************************************************
+* ¤ٴ˥塼򤷤
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt )
+{
+	char	*ret;
+
+	ret = menu_auto_mark_arrange( (long)((*pp)->arg), +1 );
+
+	set_menu_auto_mark( dflt );
+
+	return ret;
+}
+
+/***************************************************************
+* ˥塼¤ٴ
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*menu_auto_mark_arrange( long n, long d )
+{
+	long	i, j;
 	auto_mark_t	am;
 	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 
-	n = (long)((*pp)->arg);
-
-	/**/
+	if( d <= -1 )
+		d = -1;
+	else if( d >= +1 )
+		d = +1;
+	else
+		return STR_MENU_ERR;
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		am = ls_auto_mark[i][n];
 
-		for( j = n - 1; j >= 0; j-- )
-			ls_auto_mark[i][j + 1] = ls_auto_mark[i][j];
+		if( d <= -1 ){
+			for( j = n - 1; j >= 0; j-- ){
+				ls_auto_mark[i][j + 1]
+						= ls_auto_mark[i][j];
+			}
 
-		ls_auto_mark[i][0] = am;
+			ls_auto_mark[i][0] = am;
+		} else {
+			for( j = n + 1; j < AUTO_MARK_MAX_N; j++ ){
+				ls_auto_mark[i][j - 1]
+						= ls_auto_mark[i][j];
+			}
+
+			ls_auto_mark[i][AUTO_MARK_MAX_N - 1] = am;
+		}
 	}
 
 	/**/
 
-	strncpy( buf, get_msg_ttl_auto_mark( n ),
+	str_nz_cpy( buf, get_msg_ttl_auto_mark_code( n ),
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 
-	for( j = n - 1; j >= 0; j-- ){
-		strncpy( get_msg_ttl_auto_mark( j + 1 ),
-				get_msg_ttl_auto_mark( j ),
+	if( d <= -1 ){
+		for( j = n - 1; j >= 0; j-- ){
+			str_nz_cpy( get_msg_ttl_auto_mark_code( j + 1 ),
+					get_msg_ttl_auto_mark_code( j ),
+					MSG_TTL_AUTO_MARK_MAX_LEN );
+		}
+
+		str_nz_cpy( get_msg_ttl_auto_mark_code( 0 ), buf,
+				MSG_TTL_AUTO_MARK_MAX_LEN );
+	} else {
+		for( j = n + 1; j < AUTO_MARK_MAX_N; j++ ){
+			str_nz_cpy( get_msg_ttl_auto_mark_code( j - 1 ),
+					get_msg_ttl_auto_mark_code( j ),
+					MSG_TTL_AUTO_MARK_MAX_LEN );
+		}
+
+		str_nz_cpy( get_msg_ttl_auto_mark_code( j - 1 ), buf,
 				MSG_TTL_AUTO_MARK_MAX_LEN );
 	}
 
-	strncpy( get_msg_ttl_auto_mark( 0 ), buf,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
-
 	/**/
 
-	set_menu_auto_mark( dflt );
 	auto_mark_cur_n = 0;
 
-	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_ARRANGE );
+	if( d <= -1 ){
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_TOP );
+	} else {
+		print_msg( FLG_NULL,
+				MSG_MENU_AUTO_MARK_DONE_ARRANGE_BOTTOM );
+	}
 
-	return "/auto mark/0";
+	return "/auto mark";
 }
 
 /***************************************************************
@@ -2272,14 +2427,92 @@ auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr )
 /***************************************************************
 * ưޡΥȥʸ֤
 * n : ưޡֹ
-* return : ưޡΥȥʸ֤
+* return : ưޡΥȥʸ
 ***************************************************************/
 
-char	*get_msg_ttl_auto_mark( long n )
+char	*get_msg_ttl_auto_mark_code( long n )
 {
 	return msg_ttl_auto_mark[n];
 }
 
+/***************************************************************
+* ưޡΥȥ̾ʸ֤
+* n : ưޡֹ
+* return : ưޡΥȥ̾ʸ
+***************************************************************/
+
+char	*get_msg_ttl_auto_mark_name( long n )
+{
+	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+
+	str[0] = '\0';
+	str_max_n_cat( str, get_msg_ttl_auto_mark_info( n ),
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_max_n_cat( str, STR_TTL_AUTO_MARK_SPLIT_NAME,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_max_n_cat( str, get_msg_ttl_auto_mark_hint( n ),
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+
+	return str;
+}
+
+/***************************************************************
+* ưޡΥȥξܺʸ֤
+* n : ưޡֹ
+* return : ưޡΥȥξܺʸ
+***************************************************************/
+
+char	*get_msg_ttl_auto_mark_info( long n )
+{
+	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	*ttl, *p;
+
+	ttl = msg_ttl_auto_mark[n];
+
+	p = strstr( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE );
+	if( p == NULL ){
+		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_MAX_LEN );
+	} else {
+		long	len;
+
+		len = p - ttl;
+		if( len < 0 )
+			len = 0;
+		if( len > MSG_TTL_AUTO_MARK_MAX_LEN )
+			len = MSG_TTL_AUTO_MARK_MAX_LEN;
+
+		str_nz_cpy( str, ttl, len );
+	}
+
+	return str;
+}
+
+/***************************************************************
+* ưޡΥȥΥҥʸ֤
+* n : ưޡֹ
+* return : ưޡΥȥΥҥʸ
+***************************************************************/
+
+char	*get_msg_ttl_auto_mark_hint( long n )
+{
+	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	*ttl, *p;
+
+	ttl = msg_ttl_auto_mark[n];
+
+	p = strstr( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE );
+	if( p == NULL ){
+		str[0] = '\0';
+	} else {
+		long	len;
+
+		len = str_len_std( STR_TTL_AUTO_MARK_SPLIT_CODE );
+		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_MAX_LEN );
+	}
+
+	return str;
+}
+
 /***************************************************************
 * ưޡΥǡ֤
 * long ls_mbr_n : СꥹȤֹ
