@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.20 2006/01/31 10:52:09 bowkenken Exp $
+* $Id: call.cpp,v 1.23 2006/08/14 21:53:55 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -50,6 +50,13 @@ bool_t	call_game_thread_create( void *(*func)( void * ) )
 		return FALSE;
 #endif // D_WS
 
+#ifdef D_GTK
+	if( GameThreadCreate( func ) )
+		return TRUE;
+	else
+		return FALSE;
+#endif // D_GTK
+
 	return TRUE;
 }
 
@@ -72,6 +79,20 @@ void	call_gui_menu_draw( draw_menu_t *data )
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiMenu.draw( data );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -92,6 +113,20 @@ void	call_gui_menu_wipe()
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiMenu.wipe();
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -113,6 +148,20 @@ void	call_set_mouse_dflt_menu( long sel_n )
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiMenu.setMouseDfltMenu( sel_n );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -133,6 +182,23 @@ void	call_pcg_dun_reset()
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+#if 0
+//@@@
+	if( !g_flg_init )
+		return;
+#endif
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gPcgDun.reset();
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -153,6 +219,20 @@ void	call_pcg_dun_reset_update_flg()
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gPcgDun.resetUpdateFlg();
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -177,6 +257,20 @@ void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h )
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gPcgDun.draw( map_x, map_y, map_w, map_h );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -199,6 +293,20 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gPcgDun.scrollTile( map_x, map_y );
+
+	gdk_flush();
+	gdk_threads_leave();
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -219,6 +327,9 @@ void	call_stat_win_redraw()
 
 	WSGIappDev()->unlock();
 #endif // D_WS
+
+#ifdef D_GTK
+#endif // D_GTK
 }
 
 /***************************************************************
@@ -243,6 +354,8 @@ long	call_key_get_char()
 	WSGIappDev()->unlock();
 #endif // D_WS
 
+#ifdef D_GTK
+#endif // D_GTK
+
 	return c;
 }
-
