@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.97 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: chr.h,v 1.100 2006/03/09 23:31:04 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -241,6 +241,19 @@ typedef struct {
 	sex_t	cur, org;
 } sex_dat_t;
 
+/***************************************************************
+* 饯θ
+***************************************************************/
+
+typedef enum {
+	CHR_DIR_IDX_S,
+	CHR_DIR_IDX_W,
+	CHR_DIR_IDX_E,
+	CHR_DIR_IDX_N,
+	CHR_DIR_IDX_MAX_N,
+	CHR_DIR_IDX_NULL = CHR_DIR_IDX_S,
+} chr_dir_idx_t;
+
 /***************************************************************
 * ư®
 ***************************************************************/
@@ -701,6 +714,8 @@ typedef struct {
 typedef struct chr_t {
 	/* ꥹȤ */
 	struct chr_t	*prev, *next;
+	/* ޥåױ饽Ȥ饯Υꥹ */
+	struct chr_t	*sort_chr_next;
 
 	/* μ */
 	chr_kind_t	kind;
@@ -724,9 +739,14 @@ typedef struct chr_t {
 	/* ΰ */
 	long	pre_x, pre_y;
 	/*  */
+	long	pre_draw_x, pre_draw_y;
+	/*  */
 	long	dx, dy;
+	/*  */
+	chr_dir_idx_t	chr_dir_idx;
 	/* ưλ */
 	move_t	move;
+
 	/*  */
 	gold_t	gold;
 	/* ԤäΤ볬Ͼ塢ϲ */
