@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs-def.h,v 1.2 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: curs-def.h,v 1.5 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_DEF_H
@@ -178,8 +178,8 @@
 typedef struct {
 	int	n;
 } WINDOW;
-
-WINDOW	*stdscr;
 #endif	/* ! HAVE_LIBCURSES */
 
+EXTERN WINDOW	*stdscr;
+
 #endif	/* CURS_DEF_H */
