@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.65 2006/01/15 14:23:02 bowkenken Exp $
+* $Id: curs.c,v 1.66 2006/08/10 21:33:18 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -846,7 +846,7 @@ void	curs_getnstr( char *s, int len )
 #endif	/* HAVE_LIBCURSES */
 
 	fgets( buf, sizeof( buf ) - 1, stdin );
-	strncpy( s, buf, len );
+	str_nz_cpy( s, buf, len );
 }
 
 /***************************************************************
