@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.72 2006/02/01 18:35:37 bowkenken Exp $
+* $Id: gmain.c,v 1.73 2006/08/07 04:33:28 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -160,6 +160,18 @@ void	game_main( void )
 ***************************************************************/
 
 void	exit_game( long code )
+{
+	close_game( code );
+
+	exit( code );
+}
+
+/***************************************************************
+* νλν
+* long code : λ
+***************************************************************/
+
+void	close_game( long code )
 {
 	FILE	*fp;
 
@@ -173,8 +185,6 @@ void	exit_game( long code )
 		fp = stderr;
 
 	version( fp );
-
-	exit( code );
 }
 
 /***************************************************************
