@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.45 2006/01/14 16:32:16 bowkenken Exp $
+* $Id: gmain.h,v 1.46 2006/01/31 08:04:37 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -133,6 +133,9 @@ typedef enum {
 
 /* ե饰 */
 
+/* CUI ⥸塼뤬Ѥߤ? */
+EXTERN bool_t	g_flg_init;
+
 /* CUI ⡼ */
 EXTERN bool_t	g_flg_cui;
 
