@@ -7,6 +7,10 @@ extern "C" {
 void	init_var_misc_menu( void );
 void	init_misc_menu( void );
 char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
+char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt );
+bool_t	chk_continue_exec_mode( void );
+bool_t	set_continue_exec_mode( void );
+bool_t	clr_continue_exec_mode( void );
 char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
 char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
 char	*cb_menu_stairs_down( menu_t **pp, menu_t **dflt );
@@ -41,52 +45,29 @@ char	*cb_menu_formation( menu_t **pp, menu_t **dflt );
 void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n );
 char	*cb_menu_formation_sel_n( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
-char	*cb_menu_crsr_move(
-	menu_t **pp, menu_t **dflt
-);
+char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_move_stop( menu_t **pp, menu_t **dflt );
 void	move_crsr_abs( long x, long y );
 void	move_crsr_rel( long dx, long dy );
-char	*cb_menu_crsr_quick_move(
-	menu_t **pp, menu_t **dflt
-);
+char	*cb_menu_crsr_quick_move( menu_t **pp, menu_t **dflt );
 void	jump_crsr( long dx, long dy );
-char	*cb_menu_crsr_move_mbr(
-	menu_t **pp, menu_t **dflt
-);
+char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt );
 char	*menu_crsr_move_mbr_n( long mbr_n );
 char	*menu_crsr_move_mbr( mbr_t *mbr );
-char	*cb_menu_crsr_center(
-	menu_t **pp, menu_t **dflt
-);
+char	*cb_menu_crsr_center( menu_t **pp, menu_t **dflt );
 void	scroll_smooth( void );
 void	scroll_center( void );
 void	chk_scroll( bool_t flg_gui );
 void	scroll_half_page( void );
 void	move_crsr_mbr_trgt( mbr_t *mbr );
-char	*cb_menu_crsr_next_pos_mbr(
-	menu_t **pp, menu_t **dflt
-);
-char	*cb_menu_crsr_next_pos_mnstr(
-	menu_t **pp, menu_t **dflt
-);
-char	*cb_menu_crsr_next_pos_item(
-	menu_t **pp, menu_t **dflt
-);
-char	*cb_menu_crsr_next_pos_door(
-	menu_t **pp, menu_t **dflt
-);
-char	*cb_menu_crsr_next_pos_obj(
-	menu_t **pp, menu_t **dflt
-);
-char	*cb_menu_crsr_next_pos_square(
-	menu_t **pp, menu_t **dflt
-);
-char	*cb_menu_crsr_next_pos_all(
-	menu_t **pp, menu_t **dflt
-);
-char	*cb_menu_crsr_prev_pos(
-	menu_t **pp, menu_t **dflt
-);
+char	*cb_menu_crsr_next_pos_mbr( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_next_pos_mnstr( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_next_pos_item( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_next_pos_door( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_next_pos_obj( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_next_pos_square( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_next_pos_all( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_prev_pos( menu_t **pp, menu_t **dflt );
 bool_t	next_pos_mbr( long d );
 bool_t	next_pos_mnstr( long d );
 bool_t	next_pos_mnstr_sub( long *dx, long *dy, long d );
@@ -160,10 +141,12 @@ char	*get_user_menu_name( long n );
 char	*get_user_menu_cmd( long n );
 char	*cb_menu_user_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_new( menu_t **pp, menu_t **dflt );
-char	*cb_menu_user_arrange( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_top( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_bottom( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove( menu_t **pp, menu_t **dflt );
 void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl );
-char	*cb_menu_user_arrange_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_system( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
