@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.2 2006/02/03 14:21:02 bowkenken Exp $
+* $Id: imenu.c,v 1.8 2006/08/16 23:41:48 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -42,6 +42,8 @@
 
 static menu_t	*g_menu_dflt_misc;
 
+static bool_t	g_flg_continue_exec_mode;
+
 static bool_t	g_ls_flg_srch[LS_MBR_MAX_N];
 static flg_scroll_t	g_flg_scroll;
 static next_pos_t	g_next_pos;
@@ -71,6 +73,8 @@ void	init_misc_menu( void )
 
 	g_menu_dflt_misc = NULL;
 
+	g_flg_continue_exec_mode = FALSE;
+
 	for( i = 0; i < LS_MBR_MAX_N; i++ )
 		g_ls_flg_srch[i] = TRUE;
 }
@@ -87,6 +91,40 @@ char	*cb_menu_misc( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt )
+{
+	set_continue_exec_mode();
+
+	return NULL;
+}
+
+/**/
+
+bool_t	chk_continue_exec_mode( void )
+{
+	return g_flg_continue_exec_mode;
+}
+
+/**/
+
+bool_t	set_continue_exec_mode( void )
+{
+	g_flg_continue_exec_mode = TRUE;
+
+	return g_flg_continue_exec_mode;
+}
+
+/**/
+
+bool_t	clr_continue_exec_mode( void )
+{
+	g_flg_continue_exec_mode = FALSE;
+
+	return g_flg_continue_exec_mode;
+}
+
+/**/
+
 char	*cb_menu_stairs( menu_t **pp, menu_t **dflt )
 {
 	bool_t	flg_up, flg_down;
@@ -146,8 +184,8 @@ char	*cb_menu_srch( menu_t **pp, menu_t **dflt )
 	ls = ls_menu_srch;
 	k = 0;
 
-	strncpy( ls[k].path, "/search", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/search", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -157,46 +195,46 @@ char	*cb_menu_srch( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/search/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/search/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
-	strncpy( ls[k].msg, MSG_TTL_MENU_SRCH, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_SRCH, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/search/exec", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/search/exec", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = 'X';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_SRCH_EXEC, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_SRCH_EXEC, MENU_MSG_MAX_LEN );
 	ls[k].call_back = cb_menu_srch_exec;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/search/exec all", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/search/exec all", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = 'Y';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_SRCH_EXEC_ALL, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_SRCH_EXEC_ALL, MENU_MSG_MAX_LEN );
 	ls[k].call_back = cb_menu_srch_exec_all;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/search/cancel all", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/search/cancel all", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = 'Z';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_SRCH_CANCEL_ALL, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_SRCH_CANCEL_ALL, MENU_MSG_MAX_LEN );
 	ls[k].call_back = cb_menu_srch_cancel_all;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -204,23 +242,23 @@ char	*cb_menu_srch( menu_t **pp, menu_t **dflt )
 
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		sprintf( ls[k].path, "/search/%ld", i );
-		strncpy( ls[k].kind, "<CheckItem>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<CheckItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_srch_sel_mbr;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
 		k++;
 	}
 
-	strncpy( ls[k].path, "/search/auto off", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<CheckItem>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/search/auto off", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<CheckItem>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = 'V';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_SRCH_AUTO_OFF, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_SRCH_AUTO_OFF, MENU_MSG_MAX_LEN );
 	ls[k].call_back = cb_menu_srch_auto_off;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -882,6 +920,8 @@ char	*cb_menu_formation( menu_t **pp, menu_t **dflt )
 		set_menu_formation( ls_menu_formation, &dflt2,
 				get_sel_mbr_n() );
 		str = exec_menu( ls_menu_formation, dflt2, NULL );
+		if( str == NULL )
+			continue;
 		if( strcmp( str, STR_MENU_CANCEL ) != 0 )
 			break;
 	}
@@ -899,8 +939,8 @@ void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n )
 
 	*dflt = NULL;
 
-	strncpy( ls[k].path, "/formation", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/formation", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -910,13 +950,13 @@ void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/formation/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/formation/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	ls[k].msg[0] = '\0';
-	strncpy( ls[k].msg, MSG_TTL_MENU_FORMATION_SEL_N, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_FORMATION_SEL_N, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -927,7 +967,7 @@ void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n )
 			*dflt = &(ls[k]);
 
 		sprintf( ls[k].path, "/formation/%ld", i );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
@@ -999,9 +1039,7 @@ char	*cb_menu_crsr( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_crsr_move(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt )
 {
 	pos_t	*crsr = get_crsr();
 
@@ -1044,6 +1082,15 @@ char	*cb_menu_crsr_move(
 
 /**/
 
+char	*cb_menu_crsr_move_stop( menu_t **pp, menu_t **dflt )
+{
+	chk_scroll( FALSE );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
 void	move_crsr_abs( long x, long y )
 {
 	pos_t	*crsr = get_crsr();
@@ -1066,9 +1113,7 @@ void	move_crsr_rel( long dx, long dy )
 
 /**/
 
-char	*cb_menu_crsr_quick_move(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_quick_move( menu_t **pp, menu_t **dflt )
 {
 	switch( (long)((*pp)->arg) ){
 	case 1:
@@ -1220,9 +1265,7 @@ void	jump_crsr( long dx, long dy )
 
 /**/
 
-char	*cb_menu_crsr_move_mbr(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt )
 {
 	mbr_t	*mbr;
 	char	*str;
@@ -1271,9 +1314,7 @@ char	*menu_crsr_move_mbr( mbr_t *mbr )
 
 /**/
 
-char	*cb_menu_crsr_center(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_center( menu_t **pp, menu_t **dflt )
 {
 	scroll_center();
 
@@ -1382,8 +1423,7 @@ void	chk_scroll( bool_t flg_gui )
 	if( flg_gui && (draw != NULL) )
 		call_pcg_dun_scroll( draw->x, draw->y );
 
-	draw_crsr();
-	draw_sub_crsr();
+	update_crsr();
 }
 
 /**/
@@ -1493,9 +1533,7 @@ void	move_crsr_mbr_trgt( mbr_t *mbr )
 
 /**/
 
-char	*cb_menu_crsr_next_pos_mbr(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_next_pos_mbr( menu_t **pp, menu_t **dflt )
 {
 	next_pos_mbr( +1 );
 
@@ -1504,9 +1542,7 @@ char	*cb_menu_crsr_next_pos_mbr(
 
 /**/
 
-char	*cb_menu_crsr_next_pos_mnstr(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_next_pos_mnstr( menu_t **pp, menu_t **dflt )
 {
 	next_pos_mnstr( +1 );
 
@@ -1515,9 +1551,7 @@ char	*cb_menu_crsr_next_pos_mnstr(
 
 /**/
 
-char	*cb_menu_crsr_next_pos_item(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_next_pos_item( menu_t **pp, menu_t **dflt )
 {
 	next_pos_item( +1 );
 
@@ -1526,9 +1560,7 @@ char	*cb_menu_crsr_next_pos_item(
 
 /**/
 
-char	*cb_menu_crsr_next_pos_door(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_next_pos_door( menu_t **pp, menu_t **dflt )
 {
 	next_pos_door( +1 );
 
@@ -1537,9 +1569,7 @@ char	*cb_menu_crsr_next_pos_door(
 
 /**/
 
-char	*cb_menu_crsr_next_pos_obj(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_next_pos_obj( menu_t **pp, menu_t **dflt )
 {
 	next_pos_obj( +1 );
 
@@ -1548,9 +1578,7 @@ char	*cb_menu_crsr_next_pos_obj(
 
 /**/
 
-char	*cb_menu_crsr_next_pos_square(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_next_pos_square( menu_t **pp, menu_t **dflt )
 {
 	next_pos_square( +1 );
 
@@ -1559,9 +1587,7 @@ char	*cb_menu_crsr_next_pos_square(
 
 /**/
 
-char	*cb_menu_crsr_next_pos_all(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_next_pos_all( menu_t **pp, menu_t **dflt )
 {
 	next_pos_all( +1 );
 
@@ -1570,9 +1596,7 @@ char	*cb_menu_crsr_next_pos_all(
 
 /**/
 
-char	*cb_menu_crsr_prev_pos(
-	menu_t **pp, menu_t **dflt
-)
+char	*cb_menu_crsr_prev_pos( menu_t **pp, menu_t **dflt )
 {
 	prev_pos();
 
@@ -2306,9 +2330,9 @@ char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt )
 	ls = ls_menu_mbr_flg;
 	k = 0;
 
-	strncpy( ls[k].path, "/config member flag",
+	str_nz_cpy( ls[k].path, "/config member flag",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -2319,14 +2343,14 @@ char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/config member flag/title",
+	str_nz_cpy( ls[k].path, "/config member flag/title",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>",
+	str_nz_cpy( ls[k].kind, "<Title>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, ttl, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, ttl, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -2337,12 +2361,12 @@ char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt )
 			continue;
 
 		sprintf( ls[k].path, "/config member flag/%ld", i );
-		strncpy( ls[k].kind, "<CheckItem>",
+		str_nz_cpy( ls[k].kind, "<CheckItem>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, pty->mbr[i]->name,
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
 				MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb;
 		ls[k].arg = (void *)pty->mbr[i];
@@ -2513,7 +2537,7 @@ char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt )
 	k = 0;
 
 	sprintf( ls[k].path, "/lang" );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2524,11 +2548,11 @@ char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt )
 	k++;
 
 	sprintf( ls[k].path, "/lang/title" );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_LANG_LS, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_LANG_LS, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -2536,9 +2560,9 @@ char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt )
 
 	for( i = 0; i < LANG_KIND_MAX_N; i++ ){
 		if( (i != 0) && (i % MENU_LANG_LS_N_PER_PAGE == 0) ){
-			strncpy( ls[k].path, "/lang/page separator",
+			str_nz_cpy( ls[k].path, "/lang/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -2554,12 +2578,12 @@ char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt )
 			*dflt = &(ls[k]);
 
 		sprintf( ls[k].path, "/lang/%ld", (long)i );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A'
 				+ (i % MENU_LANG_LS_N_PER_PAGE));
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, get_lang_kind_name( (lang_kind_t)i ),
+		str_nz_cpy( ls[k].msg, get_lang_kind_name( (lang_kind_t)i ),
 				MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_lang_ls_sel;
 		ls[k].arg = (void *)i;
@@ -2860,7 +2884,7 @@ char	*cb_menu_color( menu_t **pp, menu_t **dflt )
 	k = 0;
 
 	sprintf( ls[k].path, "/color" );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2871,11 +2895,11 @@ char	*cb_menu_color( menu_t **pp, menu_t **dflt )
 	k++;
 
 	sprintf( ls[k].path, "/color/title" );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_COLOR, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_COLOR, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -2887,9 +2911,9 @@ char	*cb_menu_color( menu_t **pp, menu_t **dflt )
 		n = (curs_attr_n_t)i;
 		if( (n == CURS_ATTR_N_MBR_1)
 				|| (n == CURS_ATTR_N_FX_MBR_PLUS) ){
-			strncpy( ls[k].path, "/color/page separator",
+			str_nz_cpy( ls[k].path, "/color/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -2901,11 +2925,11 @@ char	*cb_menu_color( menu_t **pp, menu_t **dflt )
 			k++;
 		}
 		sprintf( ls[k].path, "/color/%ld", (long)i );
-		strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, MSG( attr[i].name_n ),
+		str_nz_cpy( ls[k].msg, MSG( attr[i].name_n ),
 				MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_color_sel;
 		ls[k].arg = (void *)&(attr[i]);
@@ -3110,7 +3134,7 @@ char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt )
 	max_n = get_crsr_ptn_max_n();
 
 	sprintf( ls[k].path, "/cursor" );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3121,11 +3145,11 @@ char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt )
 	k++;
 
 	sprintf( ls[k].path, "/cursor/title" );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_CRSR_PTN, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_CRSR_PTN, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -3133,9 +3157,9 @@ char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt )
 
 	for( i = 0; i < max_n; i++ ){
 		if( (i != 0) && (i % CRSR_PTN_MAX_N == 0) ){
-			strncpy( ls[k].path, "/cursor/page separator",
+			str_nz_cpy( ls[k].path, "/cursor/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -3153,7 +3177,7 @@ char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt )
 			*dflt = &(ls[k]);
 
 		sprintf( ls[k].path, "/cursor/%ld", (long)(i + 1) );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
@@ -3405,7 +3429,7 @@ char	*cb_menu_macro_edit( menu_t **pp, menu_t **dflt )
 				buf[len - 1] = '\0';
 
 		if( buf[0] != '\0' )
-			strncpy( get_macro( n ), buf, MACRO_MAX_LEN );
+			str_nz_cpy( get_macro( n ), buf, MACRO_MAX_LEN );
 	}
 	print_msg( FLG_MSG_DEBUG, "set macro[%ld]: \"%s\"",
 			n, get_macro( n ) );
@@ -3425,9 +3449,9 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 	k = 0;
 	key = 'A';
 
-	strncpy( ls[k].path, "/user menu",
+	str_nz_cpy( ls[k].path, "/user menu",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -3440,9 +3464,9 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 
 	for( i = 0; i < g_user_menu_n; i++ ){
 		if( (i != 0) && ((i % USER_MENU_MAX_N_PER_PAGE) == 0) ){
-			strncpy( ls[k].path, "/user menu/page separator",
+			str_nz_cpy( ls[k].path, "/user menu/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -3456,14 +3480,14 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 		}
 
 		if( (i % USER_MENU_MAX_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path, "/user menu/--",
+			str_nz_cpy( ls[k].path, "/user menu/--",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<Title>",
+			str_nz_cpy( ls[k].kind, "<Title>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			strncpy( ls[k].msg, MSG_MENU_USER,
+			str_nz_cpy( ls[k].msg, MSG_MENU_USER,
 					MENU_MSG_MAX_LEN );
 			ls[k].call_back = NULL;
 			ls[k].arg = NULL;
@@ -3472,11 +3496,11 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 		}
 
 		sprintf( ls[k].path, "/user menu/%ld", k );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, g_user_menu_name[i], MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, g_user_menu_name[i], MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_user_sel;
 		ls[k].arg = g_user_menu_cmd[i];
 		ls[k].flg = FLG_NULL;
@@ -3484,40 +3508,53 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 		key++;
 	}
 
-	strncpy( ls[k].path, "/user menu/new",
+	str_nz_cpy( ls[k].path, "/user menu/new",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<OpenWinItem>",
+	str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 			MENU_KIND_MAX_LEN );
-	ls[k].accel_key = 'X';
+	ls[k].accel_key = 'W';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_USER_NEW, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_USER_NEW, MENU_MSG_MAX_LEN );
 	ls[k].call_back = cb_menu_user_new;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/user menu/arrange",
+	str_nz_cpy( ls[k].path, "/user menu/arrange top",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
-	ls[k].accel_key = 'Y';
+	ls[k].accel_key = 'X';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_USER_ARRANGE, MENU_MSG_MAX_LEN );
-	ls[k].call_back = cb_menu_user_arrange;
+	str_nz_cpy( ls[k].msg, MSG_MENU_USER_ARRANGE_TOP, MENU_MSG_MAX_LEN );
+	ls[k].call_back = cb_menu_user_arrange_top;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/user menu/remove",
+	str_nz_cpy( ls[k].path, "/user menu/arrange bottom",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = 'Y';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	str_nz_cpy( ls[k].msg, MSG_MENU_USER_ARRANGE_BOTTOM, MENU_MSG_MAX_LEN );
+	ls[k].call_back = cb_menu_user_arrange_bottom;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	str_nz_cpy( ls[k].path, "/user menu/remove",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = 'Z';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_USER_REMOVE, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_USER_REMOVE, MENU_MSG_MAX_LEN );
 	ls[k].call_back = cb_menu_user_remove;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -3547,8 +3584,8 @@ void	add_user_menu( char *name, char *cmd )
 	if( cmd == NULL )
 		return;
 
-	strncpy( g_user_menu_name[g_user_menu_n], name, MENU_MSG_MAX_LEN );
-	strncpy( g_user_menu_cmd[g_user_menu_n], cmd, MACRO_MAX_LEN );
+	str_nz_cpy( g_user_menu_name[g_user_menu_n], name, MENU_MSG_MAX_LEN );
+	str_nz_cpy( g_user_menu_cmd[g_user_menu_n], cmd, MACRO_MAX_LEN );
 
 	g_user_menu_n++;
 }
@@ -3652,12 +3689,26 @@ char	*cb_menu_user_new( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_user_arrange( menu_t **pp, menu_t **dflt )
+char	*cb_menu_user_arrange_top( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls = ls_menu_user_edit;
 
-	set_edit_user_menu( ls, cb_menu_user_arrange_sel,
-			MSG_MENU_USER_ARRANGE );
+	set_edit_user_menu( ls, cb_menu_user_arrange_top_sel,
+			MSG_MENU_USER_ARRANGE_TOP );
+
+	exec_menu( ls, NULL, NULL );
+
+	return "/misc/config/user menu select";
+}
+
+/**/
+
+char	*cb_menu_user_arrange_bottom( menu_t **pp, menu_t **dflt )
+{
+	menu_t	*ls = ls_menu_user_edit;
+
+	set_edit_user_menu( ls, cb_menu_user_arrange_bottom_sel,
+			MSG_MENU_USER_ARRANGE_BOTTOM );
 
 	exec_menu( ls, NULL, NULL );
 
@@ -3688,9 +3739,9 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl )
 	k = 0;
 	key = 'A';
 
-	strncpy( ls[k].path, "/user menu edit",
+	str_nz_cpy( ls[k].path, "/user menu edit",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -3703,10 +3754,10 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl )
 
 	for( i = 0; i < g_user_menu_n; i++ ){
 		if( (i != 0) && ((i % USER_MENU_MAX_N_PER_PAGE) == 0) ){
-			strncpy( ls[k].path,
+			str_nz_cpy( ls[k].path,
 					"/user menu edit/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -3720,14 +3771,14 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl )
 		}
 
 		if( (i % USER_MENU_MAX_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path, "/user menu edit/--",
+			str_nz_cpy( ls[k].path, "/user menu edit/--",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<Title>",
+			str_nz_cpy( ls[k].kind, "<Title>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			strncpy( ls[k].msg, ttl, MENU_MSG_MAX_LEN );
+			str_nz_cpy( ls[k].msg, ttl, MENU_MSG_MAX_LEN );
 			ls[k].call_back = NULL;
 			ls[k].arg = NULL;
 			ls[k].flg = FLG_NULL;
@@ -3735,11 +3786,11 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl )
 		}
 
 		sprintf( ls[k].path, "/user menu edit/%ld", k );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, g_user_menu_name[i], MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, g_user_menu_name[i], MENU_MSG_MAX_LEN );
 		ls[k].call_back = func;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -3752,7 +3803,7 @@ void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl )
 
 /**/
 
-char	*cb_menu_user_arrange_sel( menu_t **pp, menu_t **dflt )
+char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt )
 {
 	long	i, n;
 	char	name[MENU_MSG_MAX_LEN + 1];
@@ -3760,20 +3811,50 @@ char	*cb_menu_user_arrange_sel( menu_t **pp, menu_t **dflt )
 
 	n = (long)((*pp)->arg);
 
-	strncpy( name, g_user_menu_name[n], MENU_MSG_MAX_LEN );
-	strncpy( cmd, g_user_menu_cmd[n], MACRO_MAX_LEN );
+	str_nz_cpy( name, g_user_menu_name[n], MENU_MSG_MAX_LEN );
+	str_nz_cpy( cmd, g_user_menu_cmd[n], MACRO_MAX_LEN );
 
-	for( i = n; i >= 1; i-- ){
-		strncpy( g_user_menu_name[i],
-				g_user_menu_name[i - 1],
+	for( i = n - 1; i >= 0; i-- ){
+		str_nz_cpy( g_user_menu_name[i + 1],
+				g_user_menu_name[i],
 				MENU_MSG_MAX_LEN );
-		strncpy( g_user_menu_cmd[i],
-				g_user_menu_cmd[i - 1],
+		str_nz_cpy( g_user_menu_cmd[i + 1],
+				g_user_menu_cmd[i],
 				MACRO_MAX_LEN );
 	}
 
-	strncpy( g_user_menu_name[0], name, MENU_MSG_MAX_LEN );
-	strncpy( g_user_menu_cmd[0], cmd, MACRO_MAX_LEN );
+	str_nz_cpy( g_user_menu_name[0], name, MENU_MSG_MAX_LEN );
+	str_nz_cpy( g_user_menu_cmd[0], cmd, MACRO_MAX_LEN );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt )
+{
+	long	i, n;
+	char	name[MENU_MSG_MAX_LEN + 1];
+	char	cmd[MENU_MSG_MAX_LEN + 1];
+
+	n = (long)((*pp)->arg);
+
+	str_nz_cpy( name, g_user_menu_name[n], MENU_MSG_MAX_LEN );
+	str_nz_cpy( cmd, g_user_menu_cmd[n], MACRO_MAX_LEN );
+
+	for( i = n + 1; i < g_user_menu_n; i++ ){
+		str_nz_cpy( g_user_menu_name[i - 1],
+				g_user_menu_name[i],
+				MENU_MSG_MAX_LEN );
+		str_nz_cpy( g_user_menu_cmd[i - 1],
+				g_user_menu_cmd[i],
+				MACRO_MAX_LEN );
+	}
+
+	str_nz_cpy( g_user_menu_name[i - 1], name,
+			MENU_MSG_MAX_LEN );
+	str_nz_cpy( g_user_menu_cmd[i - 1], cmd,
+			MACRO_MAX_LEN );
 
 	return NULL;
 }
@@ -3787,10 +3868,10 @@ char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt )
 	n = (long)((*pp)->arg);
 
 	for( i = n; i < g_user_menu_n - 1; i++ ){
-		strncpy( g_user_menu_name[i],
+		str_nz_cpy( g_user_menu_name[i],
 				g_user_menu_name[i + 1],
 				MENU_MSG_MAX_LEN );
-		strncpy( g_user_menu_cmd[i],
+		str_nz_cpy( g_user_menu_cmd[i],
 				g_user_menu_cmd[i + 1],
 				MACRO_MAX_LEN );
 	}
