@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.11 2006/02/15 00:33:03 bowkenken Exp $
+* $Id: inc.h,v 1.18 2006/08/16 23:41:48 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -38,7 +38,7 @@
 #ifdef	AMENU_C
 
 #include	"gmain.h"
-/*#include	"misc.h"*/
+#include	"misc.h"
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"town.h"*/
@@ -248,7 +248,7 @@
 #include	"curs-prot.h"
 #include	"menu-prot.h"
 #include	"mmenu-prot.h"
-/*#include	"imenu-prot.h"*/
+#include	"imenu-prot.h"
 #include	"tmenu-prot.h"
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
@@ -1319,7 +1319,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
-/*#include	"turn.h"*/
+#include	"turn.h"
 /*#include	"dun.h"*/
 #include	"town.h"
 #include	"item.h"
@@ -1341,7 +1341,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
-/*#include	"turn-prot.h"*/
+#include	"turn-prot.h"
 #include	"dun-prot.h"
 #include	"town-prot.h"
 #include	"item-prot.h"
@@ -1655,20 +1655,98 @@
 
 /***************************************************************/
 
+#ifdef	MAIN_GTK_CPP
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+/*#include	"misc-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+#include	"imenu-prot.h"
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#include	<gtk/gtk.h>
+#include	<gdk-pixbuf/gdk-pixbuf.h>
+
+#include	"main-x-prot.h"
+#include	"main-gtk-prot.h"
+#include	"call-prot.h"
+
+#include	"MouseMap.h"
+
+#include	"GlobalVar.h"
+
+#endif	/* MAIN_GTK_CPP */
+
+/***************************************************************/
+
 #ifdef	CALL_CPP
 
-# ifdef D_WS
+# if	defined( D_WS )
 #  include <WSDappDev.h>
 #  include <WSCwindow.h>
+#  include "gmain.h"
 #  include "misc.h"
 #  include "draw.h"
-#  include "draw-prot.h"
 #  include "GameThread.h"
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
 #  include "GlobalVar.h"
+#  include "gmain-prot.h"
+#  include "draw-prot.h"
+#  include "call-prot.h"
+# elif	defined( D_GTK )
+#  include "gmain.h"
+#  include "misc.h"
+#  include "draw.h"
+#  include "GameThread.h"
+#  include "GuiMenu.h"
+#  include "PcgDun.h"
+#  include "GlobalVar.h"
+#  include "gmain-prot.h"
+#  include "draw-prot.h"
 #  include "call-prot.h"
 # else
+#  include "gmain.h"
 #  include "misc.h"
 #  include "draw.h"
 #  include "call-prot.h"
