@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.73 2004/12/13 14:14:23 bowkenken Exp $
+* $Id: item.h,v 1.84 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
@@ -111,14 +111,6 @@
 #define	FACE_MNR_AMULET	'a'
 #define	FACE_MNR_NECKLACE	'n'
 
-#define	FACE_MJR_INST	FACE_MJR_MISC
-#define	FACE_MNR_INST	'i'
-#define	FACE_MNR_INST_BRASS	'b'
-#define	FACE_MNR_INST_WOODWIND	'w'
-#define	FACE_MNR_INST_STRINGED	's'
-#define	FACE_MNR_INST_PERCUSSION	'p'
-#define	FACE_MNR_INST_MISC	'm'
-
 #define	FACE_MJR_FOOD	':'
 
 #define	FACE_MJR_CHEST	'&'
@@ -135,8 +127,18 @@
 #define	FACE_MNR_PIPE	'p'
 #define	FACE_MNR_DISPOSAL	'd'
 #define	FACE_MNR_RARE_GOODS	'!'
+#define	FACE_MNR_BONE_GOOD	'+'
+#define	FACE_MNR_BONE_EVIL	'x'
 #define	FACE_MNR_JUNK	'*'
 
+#define	FACE_MJR_INST	FACE_MJR_MISC
+#define	FACE_MNR_INST	'i'
+#define	FACE_MNR_INST_BRASS	'B'
+#define	FACE_MNR_INST_WOODWIND	'W'
+#define	FACE_MNR_INST_STRINGED	'S'
+#define	FACE_MNR_INST_PERCUSSION	'P'
+#define	FACE_MNR_INST_MISC	'M'
+
 /**/
 
 #define	WPN_ATTACK_MAX_N	4
@@ -210,40 +212,32 @@
 #define	WPN_CRTCL_KNUCKLE	((rate_t)10)
 #define	WPN_CRTCL_UNARMED	((rate_t)10)
 
-#define	POTION_PRICE_A	300
-#define	POTION_PRICE_B	250
-#define	POTION_PRICE_C	200
-#define	POTION_PRICE_D	150
-#define	POTION_PRICE_E	100
+#define	POTION_PRICE_A	1000
+#define	POTION_PRICE_B	800
+#define	POTION_PRICE_C	600
+#define	POTION_PRICE_D	400
+#define	POTION_PRICE_E	200
 
-#define	SCROLL_PRICE_A	300
-#define	SCROLL_PRICE_B	250
-#define	SCROLL_PRICE_C	200
-#define	SCROLL_PRICE_D	150
-#define	SCROLL_PRICE_E	100
+#define	SCROLL_PRICE_A	1000
+#define	SCROLL_PRICE_B	800
+#define	SCROLL_PRICE_C	600
+#define	SCROLL_PRICE_D	400
+#define	SCROLL_PRICE_E	200
 
-#define	STICK_PRICE_A	300
-#define	STICK_PRICE_B	250
-#define	STICK_PRICE_C	200
-#define	STICK_PRICE_D	150
-#define	STICK_PRICE_E	100
+#define	STICK_PRICE_A	1000
+#define	STICK_PRICE_B	800
+#define	STICK_PRICE_C	600
+#define	STICK_PRICE_D	400
+#define	STICK_PRICE_E	200
 
-#define	ACCE_PRICE_A	30000
-#define	ACCE_PRICE_B	25000
-#define	ACCE_PRICE_C	20000
-#define	ACCE_PRICE_D	15000
+#define	ACCE_PRICE_A	50000
+#define	ACCE_PRICE_B	40000
+#define	ACCE_PRICE_C	30000
+#define	ACCE_PRICE_D	20000
 #define	ACCE_PRICE_E	10000
 
 /***************************************************************/
 
-/* ƥबѲǽ? */
-
-typedef enum {
-	CAN_USE_ITEM_YES,	/* ǽ */
-	CAN_USE_ITEM_REST,	/* ¤Ĥǲǽ */
-	CAN_USE_ITEM_NO,	/* Բǽ */
-} can_use_item_t;
-
 /*  */
 
 /* ֤Ѥϥ֡ǡ⽤ */
@@ -314,12 +308,13 @@ typedef enum {
 	WPN_KIND_LANCE,
 	WPN_KIND_LANCE_OF_LONGINUS,
 /* ե쥤 */
-	WPN_KIND_QUARTER_STAFF,
 	WPN_KIND_LIGHT_FLAIL,
 	WPN_KIND_HEAVY_FLAIL,
 	WPN_KIND_MORNINGSTAR,
+	WPN_KIND_NUNCHAKUS,
 /* ᥤ */
 	WPN_KIND_WOODEN_CLUB,
+	WPN_KIND_QUARTER_STAFF,
 	WPN_KIND_LIGHT_MACE,
 	WPN_KIND_HEAVY_MACE,
 /* ϥޡ */
@@ -484,6 +479,7 @@ typedef enum {
 	POTION_KIND_VANISH,
 	POTION_KIND_IRON_BODY,
 	POTION_KIND_PASSWALL,
+	POTION_KIND_SENSE_INVISIBLE,
 	POTION_KIND_RESI_PHYS,
 	POTION_KIND_RESI_HEAT,
 	POTION_KIND_RESI_COLD,
@@ -503,7 +499,6 @@ typedef enum {
 	POTION_KIND_FOOLISH,
 	POTION_KIND_ATTRACTIVE,
 	POTION_KIND_UNATTRACTIVE,
-	POTION_KIND_SENSE_INVISIBLE,
 	POTION_KIND_POW_UP_HP,
 	POTION_KIND_SPEED_UP,
 	POTION_KIND_SPEED_DOWN,
@@ -524,6 +519,7 @@ typedef enum {
 	SCROLL_KIND_NULL,
 	SCROLL_KIND_SLEEP,
 	SCROLL_KIND_IDENTIFY_ITEM,
+	SCROLL_KIND_IDENTIFY_ALL_ITEM,
 	SCROLL_KIND_DETECT_ITEM,
 	SCROLL_KIND_TELEPORT,
 	SCROLL_KIND_POW_UP_WPN_HIT,
@@ -612,6 +608,7 @@ typedef enum {
 	AMULET_KIND_RESI_STAT_VANISH,
 	AMULET_KIND_RESI_STAT_IRON_BODY,
 	AMULET_KIND_RESI_STAT_PASSWALL,
+	AMULET_KIND_RESI_STAT_SENSE_INVISIBLE,
 	AMULET_KIND_MAX_N,
 } amulet_kind_t;
 
@@ -869,6 +866,7 @@ typedef enum {
 	RARE_GOODS_KIND_TICKET_TO_PARADISE,
 	RARE_GOODS_KIND_CALL_OF_HADES,
 	RARE_GOODS_KIND_MEMORIES_OF_THE_GOLDEN_AGE,
+	RARE_GOODS_KIND_ISNT_REALIZED,
 	RARE_GOODS_KIND_MAX_N,
 } rare_goods_kind_t;
 
@@ -899,7 +897,8 @@ typedef unsigned long	flg_wpn_tab_t;
 
 #define	FLG_WPN_TAB_BOW	(1 << 0)	/*  */
 #define	FLG_WPN_TAB_ARW	(1 << 1)	/*  */
-#define	FLG_WPN_TAB_TWO_HANDED	(1 << 2)	/* ξ */
+#define	FLG_WPN_TAB_TWO_HANDED	(1 << 2)	/* ɬξ */
+#define	FLG_WPN_TAB_CAN_TWO_HANDED	(1 << 3)	/* ξǽ */
 #define	FLG_WPN_TAB_RET	(1 << 4)	/* ä */
 #define	FLG_WPN_TAB_BUNDLE	(1 << 5)	/* «ͤ */
 #define	FLG_WPN_TAB_NOT_SPEND	(1 << 6)	/* 񤷤ʤ */
@@ -1004,6 +1003,11 @@ typedef struct {
 	mnstr_kind_t	mnstr_kind;	/* äƤ󥹥μ */
 } rare_goods_t;
 
+typedef struct {
+	mnstr_tab_t	*mnstr_tab;
+	long	dun_lev;
+} bone_t;
+
 typedef struct {
 	coin_kind_t	kind;
 } coin_t;
@@ -1422,6 +1426,8 @@ typedef struct {
 	pipe_kind_t	pipe;
 	rare_goods_kind_t	rare_goods;
 	coin_kind_t	coin;
+
+	mnstr_kind_t	mnstr;
 } item_kind_dat_t;
 
 /***************************************************************/
@@ -1493,6 +1499,7 @@ typedef struct item_t {
 		pipe_t	pipe;
 		disposal_t	disposal;
 		rare_goods_t	rare_goods;
+		bone_t	bone;
 		coin_t	coin;
 	} dat;
 } item_t;
