@@ -2,15 +2,17 @@
 
 #### Set locale ####
 
-#LANG="ja_JP.eucJP"
+LANG="ja_JP.eucJP"
 #LANG="ja_JP.ujis"
 #LANG="ja_JP.UTF-8"
 
-#export LANG
+export LANG
 
-#### Start game ####
+#### Help ####
 
 # Print Help
 #./lnl -h
 
+#### Start game ####
+
 ./lnl
