@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.180 2006/02/02 19:37:24 bowkenken Exp $
+* $Id: menu.c,v 1.182 2006/08/13 20:02:58 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -90,10 +90,10 @@ static macro_short_key_t
 	{ NULL, NULL },	/* F6 */
 	{ NULL, NULL },	/* F7 */
 	{ NULL, NULL },	/* F8 */
-	{ "/", "x" },	/* F9 */
-	{ "*", "a" },	/* F10 */
-	{ "-", "c" },	/* F11 */
-	{ "+", "v" },	/* F12 */
+	{ NULL, "x" },	/* F9 */
+	{ NULL, "a" },	/* F10 */
+	{ NULL, "c" },	/* F11 */
+	{ NULL, "v" },	/* F12 */
 };
 
 static bool_t	g_flg_dup_short_key[256];
@@ -123,7 +123,7 @@ void	init_menu( void )
 		g_macro[i][0] = '\0';
 
 		if( g_ls_macro_short_key[i].dflt != NULL ){
-			strncpy( g_macro[i],
+			str_nz_cpy( g_macro[i],
 					g_ls_macro_short_key[i].dflt,
 					MACRO_MAX_LEN );
 		}
@@ -142,8 +142,8 @@ void	init_ls_menu_macro( void )
 	ls = ls_menu_macro;
 	k = 0;
 
-	strncpy( ls[k].path, "/macro", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/macro", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].msg[0] = '\0';
@@ -152,11 +152,11 @@ void	init_ls_menu_macro( void )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/macro/--", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/macro/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
-	strncpy( ls[k].msg, MSG_MENU_MACRO, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_MACRO, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -164,7 +164,7 @@ void	init_ls_menu_macro( void )
 
 	for( i = 1; i <= FUNC_KEY_MAX_N; i++ ){
 		sprintf( ls[k].path, "/macro/%ld", i );
-		strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + (i - 1));
 		ls[k].short_key[0] = '\0';
 		sprintf( ls[k].msg, MSG_MENU_FUNC_KEY, i );
@@ -174,7 +174,7 @@ void	init_ls_menu_macro( void )
 		k++;
 
 		sprintf( ls[k].path, "/macro/%ld/--", i );
-		strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		sprintf( ls[k].msg, MSG_MENU_FUNC_KEY, i );
@@ -184,7 +184,7 @@ void	init_ls_menu_macro( void )
 		k++;
 
 		sprintf( ls[k].path, "/macro/%ld/exec", i );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'X';
 		if( g_ls_macro_short_key[i].key == NULL ){
 			sprintf( ls[k].short_key, "&%02ld", i );
@@ -192,17 +192,17 @@ void	init_ls_menu_macro( void )
 			sprintf( ls[k].short_key, "%s &%02ld",
 					g_ls_macro_short_key[i].key, i );
 		}
-		strncpy( ls[k].msg, MSG_MENU_MACRO_EXEC, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, MSG_MENU_MACRO_EXEC, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_macro_exec;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
 		k++;
 
 		sprintf( ls[k].path, "/macro/%ld/edit", i );
-		strncpy( ls[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'E';
 		ls[k].short_key[0] = '\0';
-		strncpy( ls[k].msg, MSG_MENU_MACRO_EDIT, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, MSG_MENU_MACRO_EDIT, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_macro_edit;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -416,7 +416,7 @@ ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel )
 	if( ttl == NULL )
 		p->msg[0] = '\0';
 	else
-		strncpy( p->msg, ttl, MENU_MSG_MAX_LEN );
+		str_nz_cpy( p->msg, ttl, MENU_MSG_MAX_LEN );
 
 	while( 1 ){
 		str_goto = exec_menu( ls_menu_ask, NULL, NULL );
@@ -821,7 +821,7 @@ long	set_ls_menu(
 			break;
 
 		if( tmp_p->msg[0] == '\0' )
-			strncpy( tmp_p->msg, MSG( tmp_p->n_msg ),
+			str_nz_cpy( tmp_p->msg, MSG( tmp_p->n_msg ),
 					MENU_MSG_MAX_LEN );
 
 		if( page_n == page_sel_n ){
@@ -1025,7 +1025,7 @@ bool_t	equ_flg_menu(
 	path[0] = '\0';
 	if( sub_path != NULL ){
 		if( strcmp( p->path, "/" ) != 0 )
-			strncpy( path, p->path, len );
+			str_nz_cpy( path, p->path, len );
 		str_max_n_cat( path, "/", len );
 		str_max_n_cat( path, sub_path, len );
 	}
