@@ -14,15 +14,17 @@ long	randm( long n );
 long	randm_sub( long n );
 bool_t	rate_randm( rate_t rate );
 bool_t	per_randm( long per );
+rate_t	modified_rate( rate_t rate, long n );
 bool_t	chk_ver_old( const ver_t *ver, long mjr, long mnr, long pat );
 bool_t	chk_ver_match( const ver_t *ver, long mjr, long mnr, long pat );
-rate_t	modified_rate( rate_t rate, long n );
 long	str_len_draw( const char *s );
 long	str_len_draw_english( const char *s );
 long	str_len_draw_japanese_euc( const char *s );
 long	str_len_draw_japanese_utf_8( const char *s );
 long	str_len_std( const char *s );
+char	*str_nz_cpy( char *dst, const char *src, int len );
 char	*str_max_n_cat( char *dst, const char *src, int len );
+void	str_trim_tail( char *str, const char *spc_char );
 bool_t	chk_flg( unsigned long var, unsigned long flg );
 bool_t	chk_flg_or( unsigned long var, unsigned long flg );
 void	*alloc_mem( long size, bool_t flg_exit );
