@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.34 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: misc.c,v 1.36 2006/08/11 00:43:13 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -424,6 +424,22 @@ long	str_len_std( const char *s )
 	return( (long)strlen( s ) );
 }
 
+/***************************************************************
+* ʸʸԡ롣̥ʸɬԡ
+* char *dst : Ϣʸ
+* const char *src : ȸʸ
+* int len : ʸ
+* return : Ϣʸ
+***************************************************************/
+
+char	*str_nz_cpy( char *dst, const char *src, int len )
+{
+	strncpy( dst, src, len );
+	dst[len] = '\0';
+
+	return dst;
+}
+
 /***************************************************************
 * ʸʸۤʤͤϢ뤹
 * char *dst : Ϣʸ
@@ -437,6 +453,40 @@ char	*str_max_n_cat( char *dst, const char *src, int len )
 	return strncat( dst, src, len - strlen( dst ) );
 }
 
+/***************************************************************
+* ʸζʸ
+* char *str : ʸ
+* const char *spc_char : ʸ
+***************************************************************/
+
+void	str_trim_tail( char *str, const char *spc_char )
+{
+	long	idx, next_idx;
+	long	i;
+
+	idx = 0;
+	for( i = 0; i < LOOP_MAX_10000; i++ ){
+		next_idx = idx + strcspn( &(str[idx]), spc_char );
+		if( str[next_idx] == '\0' ){
+			if( i == 0 ){
+				return;
+			} else {
+				break;
+			}
+		}
+
+		idx = next_idx;
+
+		next_idx = idx + strspn( &(str[idx]), spc_char );
+		if( str[next_idx] == '\0' )
+			break;
+
+		idx = next_idx;
+	}
+
+	str[idx] = '\0';
+}
+
 /***************************************************************
 * ե饰λꤷӥåȤΩäƤ뤫Ĵ٤
 * unsigned long var : ե饰
