@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.6 2006/02/16 01:41:01 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.10 2006/08/16 23:41:48 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -299,7 +299,7 @@ menu_t	ls_menu_main[] = {
 		"/move",
 		"<Item>",
 		'V',
-		"v",
+		"+ v",
 		N_MSG_MENU_MOVE, "",
 		cb_menu_move, NULL,
 		FLG_NULL,
@@ -308,7 +308,7 @@ menu_t	ls_menu_main[] = {
 		"/exec",
 		"<Item>",
 		'X',
-		". 5",
+		"5 .",
 		N_MSG_MENU_EXEC, "",
 		cb_menu_exec, NULL,
 		FLG_NULL,
@@ -317,7 +317,7 @@ menu_t	ls_menu_main[] = {
 		"/auto mark",
 		"<Branch>",
 		'A',
-		"a",
+		"* a",
 		N_MSG_MENU_SEL_OBJ_AUTO, "",
 		cb_menu_auto_mark, NULL,
 		FLG_NULL,
@@ -353,13 +353,22 @@ menu_t	ls_menu_main[] = {
 		"/spell",
 		"<Branch>",
 		'C',
-		"c",
+		"- c",
 		N_MSG_MENU_SPELL, "",
 		cb_menu_sel_spell, NULL,
 		FLG_NULL,
 	},
 	{
-		"/navi",
+		"/town",
+		"<Branch>",
+		'T',
+		"",
+		N_MSG_MENU_TOWN, "",
+		cb_menu_town_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/town/navi",
 		"<Branch>",
 		'N',
 		"",
@@ -367,6 +376,15 @@ menu_t	ls_menu_main[] = {
 		cb_menu_navi_init, NULL,
 		FLG_NULL,
 	},
+	{
+		"/town/auto sale",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_AUTO_SALE, "",
+		cb_menu_auto_sale, NULL,
+		FLG_NULL,
+	},
 /* misc begin */
 	{
 		"/misc",
@@ -377,6 +395,15 @@ menu_t	ls_menu_main[] = {
 		cb_menu_misc, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/continue exec",
+		"<Item>",
+		'X',
+		",",
+		N_MSG_MENU_CONTINUE_EXEC, "",
+		cb_menu_continue_exec, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/stairs",
 		"<Branch>",
@@ -923,8 +950,8 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/config/user menu select",
 		"<Branch>",
-		'M',
-		"x",
+		'U',
+		"/ x",
 		N_MSG_MENU_USER, "",
 		cb_menu_user, NULL,
 		FLG_NULL,
