@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.6 2006/02/16 03:24:38 bowkenken Exp $
+* $Id: mmenu.c,v 1.11 2006/08/12 04:22:56 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -128,9 +128,9 @@ char	*exec_menu_sel_mbr(
 	ls = ls_menu_mbr;
 	k = 0;
 
-	strncpy( ls[k].path, "/member",
+	str_nz_cpy( ls[k].path, "/member",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -141,13 +141,13 @@ char	*exec_menu_sel_mbr(
 	k++;
 
 	if( ttl != NULL ){
-		strncpy( ls[k].path, "/member/--",
+		str_nz_cpy( ls[k].path, "/member/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<Title>",
+		str_nz_cpy( ls[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
-		strncpy( ls[k].msg, ttl,
+		str_nz_cpy( ls[k].msg, ttl,
 				MENU_MSG_MAX_LEN );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
@@ -166,11 +166,11 @@ char	*exec_menu_sel_mbr(
 			dflt = &(ls[k]);
 
 		sprintf( ls[k].path, "/member/%ld", i );
-		strncpy( ls[k].kind, "<Item>",
+		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
-		strncpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_sel_mbr;
 		ls[k].arg = (void *)(pty->mbr[i]);
 		ls[k].flg = FLG_NULL;
@@ -193,11 +193,11 @@ char	*exec_menu_sel_mbr(
 			dflt = &(ls[k]);
 
 		sprintf( ls[k].path, "/member/%ld", MBR_MAX_N + i );
-		strncpy( ls[k].kind, "<Item>",
+		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + MBR_MAX_N + i);
 		ls[k].short_key[0] = '\0';
-		strncpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_sel_mbr;
 		ls[k].arg = (void *)(pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -280,7 +280,7 @@ char	*exec_menu_race( race_t *race )
 		return str_goto;
 	}
 
-	strncpy( g_sel_race.name, get_race_str_main( &g_sel_race ),
+	str_nz_cpy( g_sel_race.name, get_race_str_main( &g_sel_race ),
 			RACE_NAME_MAX_LEN );
 
 	*race = g_sel_race;
@@ -342,8 +342,8 @@ char	*exec_menu_class( long *class_n )
 	dflt = &(ls[0]);
 	k = 0;
 
-	strncpy( ls[k].path, "/class", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/class", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].msg[0] = '\0';
@@ -352,11 +352,11 @@ char	*exec_menu_class( long *class_n )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/class/--", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/class/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
-	strncpy( ls[k].msg, MSG_TTL_MENU_CLASS, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_CLASS, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -370,10 +370,10 @@ char	*exec_menu_class( long *class_n )
 			dflt = &(ls[k]);
 
 		sprintf( ls[k].path, "/class/%ld", i );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + (i % LS_CLASS_N_PER_PAGE));
 		ls[k].short_key[0] = '\0';
-		strncpy( ls[k].msg, class_tab[i].name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, class_tab[i].name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_class;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -381,9 +381,9 @@ char	*exec_menu_class( long *class_n )
 
 		if( (i % LS_CLASS_N_PER_PAGE)
 				== (LS_CLASS_N_PER_PAGE - 1) ){
-			strncpy( ls[k].path, "/class/--",
+			str_nz_cpy( ls[k].path, "/class/--",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -444,15 +444,12 @@ char	*cb_menu_main_init( menu_t **pp, menu_t **dflt )
 
 	if( g_sel_mbr_n <= -1 ){
 		/* СꤷƤʤ */
-		set_flg_menu( *pp, "item", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "equip", FLG_MENU_HIDDEN );
 		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "spell", FLG_MENU_HIDDEN );
 	}
 
 	if( dun->lev != 0 ){
 		/* ʳ */
-		set_flg_menu( *pp, "navi", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "town", FLG_MENU_HIDDEN );
 	}
 
 	return NULL;
@@ -917,7 +914,7 @@ bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 )
 		return FALSE;
 
 	mbr->act.dflt_kind_mnstr = mbr->act.kind;
-	strncpy( mbr->act.dflt_msg_mnstr, mbr->act.msg, ACT_MSG_MAX_LEN );
+	str_nz_cpy( mbr->act.dflt_msg_mnstr, mbr->act.msg, ACT_MSG_MAX_LEN );
 
 	mark_mnstr( mbr, mnstr, g_sel_dist );
 
@@ -1062,7 +1059,7 @@ bool_t	menu_mark_pos( pos_t pos1, pos_t pos2 )
 	if( !set_chr_act( mbr, ACT_KIND_NULL, NULL, NULL, 0, 0 ) )
 		return FALSE;
 
-	strncpy( mbr->act.msg, MSG_TRGT_POS, ACT_MSG_MAX_LEN );
+	str_nz_cpy( mbr->act.msg, MSG_TRGT_POS, ACT_MSG_MAX_LEN );
 	mark_pos( mbr, pos2.x, pos2.y, DIST_NEAR );
 
 	draw_mbr_stat( mbr );
@@ -1272,12 +1269,19 @@ char	*cb_menu_dist_act( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 {
+	static long pre_sel_mbr_n = 0;
 	party_t	*pty = get_party();
 	menu_t	*ls;
 	mbr_t	*mbr;
 	long	i, j, k;
 
 	if( g_sel_mbr_n <= -1 )
+		g_sel_mbr_n = pre_sel_mbr_n;
+	else
+		pre_sel_mbr_n = g_sel_mbr_n;
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n >= MBR_MAX_N )
 		return STR_MENU_ERR;
 	mbr = pty->mbr[g_sel_mbr_n];
 
@@ -1297,8 +1301,8 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 	ls = ls_menu_item;
 	k = 0;
 
-	strncpy( ls[k].path, "/item", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/item", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -1314,12 +1318,12 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 		if( chk_flg( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		strncpy( ls[k].path, "/item/--", MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].path, "/item/--", MENU_PATH_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -1333,7 +1337,7 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 
 			sprintf( ls[k].path, "/item/%ld%c",
 					i, (char)('A' + j) );
-			strncpy( ls[k].kind, "<Branch>",
+			str_nz_cpy( ls[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = (char)('A' + j);
 			ls[k].short_key[0] = '\0';
@@ -1346,20 +1350,20 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 		}
 
 		sprintf( ls[k].path, "/item/%ld%s", i, "equip" );
-		strncpy( ls[k].kind, "<Branch>",
+		str_nz_cpy( ls[k].kind, "<Branch>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, MSG_MENU_ITEM_LS_EQUIP,
+		str_nz_cpy( ls[k].msg, MSG_MENU_ITEM_LS_EQUIP,
 				MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_goto_equip;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		strncpy( ls[k].path, "/item/--", MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<PageSeparator>",
+		str_nz_cpy( ls[k].path, "/item/--", MENU_PATH_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
@@ -1659,7 +1663,7 @@ char	*cb_menu_item_smoke( menu_t **pp, menu_t **dflt )
 	if( ret == NULL ){
 		mbr->act.n = EQUIP_KIND_HEAD;
 
-		strncpy( mbr->act.msg, MSG_ACT_TOBACCO_SMOKE,
+		str_nz_cpy( mbr->act.msg, MSG_ACT_TOBACCO_SMOKE,
 				ACT_MSG_MAX_LEN );
 	}
 
@@ -1868,6 +1872,7 @@ long	get_equip_ttl_max_len( void )
 
 char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 {
+	long	pre_sel_mbr_n = 0;
 	party_t	*pty = get_party();
 	menu_t	*ls;
 	mbr_t	*mbr;
@@ -1875,6 +1880,12 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 	long	i, j, k;
 
 	if( g_sel_mbr_n <= -1 )
+		g_sel_mbr_n = pre_sel_mbr_n;
+	else
+		pre_sel_mbr_n = g_sel_mbr_n;
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n >= MBR_MAX_N )
 		return STR_MENU_ERR;
 	mbr = pty->mbr[g_sel_mbr_n];
 
@@ -1896,9 +1907,9 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 	ls = ls_menu_equip;
 	k = 0;
 
-	strncpy( ls[k].path, "/equip",
+	str_nz_cpy( ls[k].path, "/equip",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -1915,14 +1926,14 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 		if( chk_flg( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		strncpy( ls[k].path, "/equip/--",
+		str_nz_cpy( ls[k].path, "/equip/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<Title>",
+		str_nz_cpy( ls[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg,
+		str_nz_cpy( ls[k].msg,
 				pty->mbr[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
@@ -1940,7 +1951,7 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 
 			sprintf( ls[k].path, "/equip/%ld%c",
 					i, (char)('A' + j) );
-			strncpy( ls[k].kind, "<Branch>",
+			str_nz_cpy( ls[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = (char)('A' + j);
 			ls[k].short_key[0] = '\0';
@@ -1965,12 +1976,12 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 
 		sprintf( ls[k].path,
 				"/equip/%ld%s", i, "item" );
-		strncpy( ls[k].kind, "<Branch>",
+		str_nz_cpy( ls[k].kind, "<Branch>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg,
+		str_nz_cpy( ls[k].msg,
 				MSG_MENU_EQUIP_LS_ITEM,
 				MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_goto_item;
@@ -1978,9 +1989,9 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		strncpy( ls[k].path, "/equip/--",
+		str_nz_cpy( ls[k].path, "/equip/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<PageSeparator>",
+		str_nz_cpy( ls[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
@@ -2079,8 +2090,8 @@ char	*menu_equip_wear_sel( menu_t **pp, menu_t **dflt )
 	ls = ls_menu_equip_wear_sel;
 	k = 0;
 
-	strncpy( ls[k].path, "/wear", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/wear", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2097,11 +2108,11 @@ char	*menu_equip_wear_sel( menu_t **pp, menu_t **dflt )
 			break;
 
 		sprintf( ls[k].path, "/wear/%c", (char)('A' + i) );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_equip_wear;
 		ls[k].arg = p;
 		ls[k].flg = FLG_NULL;
@@ -2432,8 +2443,8 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 	k = 0;
 	key = 'A';
 
-	strncpy( ls[k].path, "/save load list", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/save load list", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2449,10 +2460,10 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 		if( (i != 0) && (i % MENU_SAVE_LOAD_N_PER_PAGE == 0) ){
 			key = 'A';
 
-			strncpy( ls[k].path,
+			str_nz_cpy( ls[k].path,
 					"/save load list/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -2471,7 +2482,7 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 		}
 
 		sprintf( ls[k].path, "/save load list/%ld", i );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
@@ -2512,25 +2523,25 @@ void	set_ttl_menu_save_load(
 	menu_t *ls, bool_t flg_save, bool_t flg_txt
 )
 {
-	strncpy( ls->path, "/save load list/title", MENU_PATH_MAX_LEN );
-	strncpy( ls->kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls->path, "/save load list/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls->kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls->accel_key = '\0';
 	ls->short_key[0] = '\0';
 	ls->n_msg = N_MSG_NULL;
 	if( flg_txt ){
 		if( flg_save ){
-			strncpy( ls->msg, MSG_MENU_WIZARD_TEXT_SAVE,
+			str_nz_cpy( ls->msg, MSG_MENU_WIZARD_TEXT_SAVE,
 					MENU_MSG_MAX_LEN );
 		} else {
-			strncpy( ls->msg, MSG_MENU_WIZARD_TEXT_LOAD,
+			str_nz_cpy( ls->msg, MSG_MENU_WIZARD_TEXT_LOAD,
 					MENU_MSG_MAX_LEN );
 		}
 	} else {
 		if( flg_save ){
-			strncpy( ls->msg, MSG_MENU_BAR_SAVE,
+			str_nz_cpy( ls->msg, MSG_MENU_BAR_SAVE,
 					MENU_MSG_MAX_LEN );
 		} else {
-			strncpy( ls->msg, MSG_MENU_BAR_LOAD,
+			str_nz_cpy( ls->msg, MSG_MENU_BAR_LOAD,
 					MENU_MSG_MAX_LEN );
 		}
 	}
@@ -2589,9 +2600,9 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 	dflt = NULL;
 	k = 0;
 
-	strncpy( ls[k].path, "/identify item",
+	str_nz_cpy( ls[k].path, "/identify item",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -2608,13 +2619,13 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 		if( chk_flg( pty->mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		strncpy( ls[k].path, "/identify item/--",
+		str_nz_cpy( ls[k].path, "/identify item/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -2632,20 +2643,20 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 			sprintf( ls[k].path,
 					"/identify item/%c",
 					(char)('A' + j) );
-			strncpy( ls[k].kind, "<Item>",
+			str_nz_cpy( ls[k].kind, "<Item>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = (char)('A' + j);
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			strncpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
+			str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
 			ls[k].call_back = cb_menu_identify_item;
 			ls[k].arg = (void *)p;
 			ls[k].flg = FLG_NULL;
 		}
 
-		strncpy( ls[k].path, "/identify item/--",
+		str_nz_cpy( ls[k].path, "/identify item/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<PageSeparator>",
+		str_nz_cpy( ls[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
@@ -2710,9 +2721,9 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 	ls = ls_menu_resurrection;
 	k = 0;
 
-	strncpy( ls[k].path, "/resurrection",
+	str_nz_cpy( ls[k].path, "/resurrection",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>",
+	str_nz_cpy( ls[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -2723,14 +2734,14 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/resurrection/--",
+	str_nz_cpy( ls[k].path, "/resurrection/--",
 			MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>",
+	str_nz_cpy( ls[k].kind, "<Title>",
 			MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_TTL_MENU_RESURRECTION,
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_RESURRECTION,
 			MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
@@ -2745,12 +2756,12 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 
 		sprintf( ls[k].path, "/resurrection/%c",
 				(char)('A' + i) );
-		strncpy( ls[k].kind, "<Item>",
+		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_resurrection;
 		ls[k].arg = pty->mbr[i];
 		ls[k].flg = FLG_NULL;
@@ -2768,12 +2779,12 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 
 		sprintf( ls[k].path, "/resurrection/%c",
 				(char)('A' + i + MBR_MAX_N) );
-		strncpy( ls[k].kind, "<Item>",
+		str_nz_cpy( ls[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i + MBR_MAX_N);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_resurrection;
 		ls[k].arg = pet[i];
 		ls[k].flg = FLG_NULL;
@@ -2848,8 +2859,9 @@ void	set_menu_dflt_main( menu_t *p )
 void	update_crsr( void )
 {
 	draw_crsr();
+	draw_sub_crsr();
+
 	reset_crsr();
-	g_pre_crsr = g_crsr;
 }
 
 /**/
