@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.168 2006/02/03 14:21:02 bowkenken Exp $
+* $Id: mnstr.c,v 1.172 2006/08/10 21:33:19 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -170,8 +170,11 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->y = MAP_DEL_Y;
 	mnstr->pre_x = MAP_DEL_X;
 	mnstr->pre_y = MAP_DEL_Y;
+	mnstr->pre_draw_x = MAP_DEL_X;
+	mnstr->pre_draw_y = MAP_DEL_Y;
 	mnstr->dx = 1;
 	mnstr->dy = 1;
+	mnstr->chr_dir_idx = CHR_DIR_IDX_NULL;
 
 	mnstr->move.speed.rate = _100_PERCENT;
 	mnstr->move.speed.rate_org = _100_PERCENT;
@@ -190,7 +193,7 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->trgt.dflt_dist_mnstr = DIST_NEAR;
 	mnstr->act.dflt_kind_mnstr
 			= ACT_KIND_MNSTR_FIGHT;
-	strncpy( mnstr->act.dflt_msg_mnstr,
+	str_nz_cpy( mnstr->act.dflt_msg_mnstr,
 			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_LEN );
 	clr_chr_trgt_act( mnstr, TRUE );
 	mnstr->pre_act = mnstr->act;
@@ -397,7 +400,7 @@ mnstr_t	*make_mnstr_alloc(
 
 	new_mnstr( p );
 
-	strncpy( p->name, tab->name, MNSTR_NAME_MAX_LEN );
+	str_nz_cpy( p->name, tab->name, MNSTR_NAME_MAX_LEN );
 	p->x = MAP_DEL_X;
 	p->y = MAP_DEL_Y;
 	p->pre_x = p->x;
@@ -774,7 +777,7 @@ mbr_t	*mnstr_mark_mbr_common( mnstr_t *p, sex_t sex )
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 			continue;
 		}
-		if( !chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
+		if( !chk_flg_work_find_mbr( p ) ){
 			if( !chk_find_chr( p, pty->mbr[i] ) ){
 				continue;
 			}
@@ -802,7 +805,7 @@ mbr_t	*mnstr_mark_mbr_common( mnstr_t *p, sex_t sex )
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
 			continue;
 		}
-		if( !chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
+		if( !chk_flg_work_find_mbr( p ) ){
 			if( !chk_find_chr( p, pty_pet[i] ) )
 				continue;
 		}
@@ -827,7 +830,7 @@ mbr_t	*mnstr_mark_mbr_common( mnstr_t *p, sex_t sex )
 
 	/* Ĥ */
 
-	p->work.flg |= FLG_WORK_FIND_MBR;
+	set_flg_work_find_mbr( p, TRUE );
 
 	p->trgt.kind = trgt_kind;
 	p->trgt.p = mark_p;
@@ -909,7 +912,7 @@ mbr_t	*mnstr_mark_mbr_adjoin( mnstr_t *p )
 	/* Ĥ */
 
 	p->flg_map |= FLG_MAP_CHR_FIND;
-	p->work.flg |= FLG_WORK_FIND_MBR;
+	set_flg_work_find_mbr( p, TRUE );
 
 	if( chk_flg( p->flg_map, FLG_MAP_CHR_INVISIBLE )
 			|| chk_flg( p->stat, FLG_STAT_VANISH ) ){
@@ -1266,6 +1269,62 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	return( chk_flg( p->flg_map, FLG_MAP_CHR_FIND ) );
 }
 
+/***************************************************************
+* 󥹥Сȯ֤Υե饰Ĵ٤
+* mnstr_t *p : 󥹥
+* return : ȯ֤Υե饰
+***************************************************************/
+
+bool_t	chk_flg_work_find_mbr( mnstr_t *p )
+{
+	if( p == NULL )
+		return FALSE;
+
+	return( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) );
+}
+
+/***************************************************************
+* 󥹥Сȯ֤Υե饰ꤹ
+* mnstr_t *p : 󥹥
+* bool_t flg : ȯ֤Υե饰
+***************************************************************/
+
+void	set_flg_work_find_mbr( mnstr_t *p, bool_t flg )
+{
+	if( p == NULL )
+		return;
+
+	if( flg ){
+		if( !chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+			chk_boss_find_mbr( p );
+
+		p->work.flg |= FLG_WORK_FIND_MBR;
+	} else {
+		p->work.flg &= ~(FLG_WORK_FIND_MBR);
+	}
+}
+
+/***************************************************************
+* ܥСȯ˥åɽ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	chk_boss_find_mbr( mnstr_t *p )
+{
+	if( p == NULL )
+		return;
+	if( p->kind != CHR_KIND_MNSTR )
+		return;
+	if( p->mnstr_tab == NULL )
+		return;
+	if( !(p->mnstr_tab->flg_boss) )
+		return;
+
+	curs_attrset_chr( p, +1, TRUE );
+	print_msg( FLG_NULL, MSG_BOSS_FIND_MBR, p->name );
+	curs_attrset_dflt();
+}
+
 /***************************************************************
 * ƤΥ󥹥ˤĤ櫤˳ݤäå
 ***************************************************************/
