@@ -66,7 +66,7 @@ long	next_ls_mbr( long ls_mbr_n, long add );
 class_t	*get_class_tab( void );
 bool_t	remove_class( long class_n );
 bool_t	cmp_class( class_t *org, class_t *dst );
-void	arrange_class( long class_n );
+void	arrange_class( long class_n, long d );
 square_t	*get_square_mbr( void );
 void	set_square_mbr( square_t *sq );
 
