@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.167 2006/01/15 14:05:51 bowkenken Exp $
+* $Id: party.c,v 1.172 2006/08/10 21:33:19 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -170,7 +170,7 @@ void	init_party( void )
 		if( class_tab[j].n_name == N_MSG_NULL )
 			break;
 
-		strncpy( class_tab[j].name,
+		str_nz_cpy( class_tab[j].name,
 				MSG( class_tab[j].n_name ),
 				CLASS_NAME_MAX_LEN );
 	}
@@ -210,49 +210,49 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_FIGHTER, 0 );
 
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
 
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
 
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
 
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
-	strncpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
-	strncpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
 
@@ -409,49 +409,49 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_NINJA, 0 );
 
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
 
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
 
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
 
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
-	strncpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
-	strncpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
 
@@ -1113,7 +1113,7 @@ void	new_mbr(
 	mbr->prev = NULL;
 	mbr->next = NULL;
 	mbr->kind = CHR_KIND_MBR;
-	strncpy( mbr->name, name, MBR_NAME_MAX_LEN );
+	str_nz_cpy( mbr->name, name, MBR_NAME_MAX_LEN );
 	mbr->mbr_n = MBR_N_NOT_JOIN;
 	mbr->ls_mbr_n = ls_mbr_n;
 	mbr->face.mjr = FACE_MJR_MBR;
@@ -1127,8 +1127,11 @@ void	new_mbr(
 	mbr->y = MAP_DEL_Y;
 	mbr->pre_x = MAP_DEL_X;
 	mbr->pre_y = MAP_DEL_Y;
+	mbr->pre_draw_x = MAP_DEL_X;
+	mbr->pre_draw_y = MAP_DEL_Y;
 	mbr->dx = 1;
 	mbr->dy = 1;
+	mbr->chr_dir_idx = CHR_DIR_IDX_NULL;
 
 	mbr->move.speed.rate = _100_PERCENT;
 	mbr->move.speed.rate_org = _100_PERCENT;
@@ -1153,7 +1156,7 @@ void	new_mbr(
 	mbr->trgt.dist = DIST_NEAR;
 	mbr->trgt.dflt_dist_mnstr = DIST_NEAR;
 	mbr->act.dflt_kind_mnstr = ACT_KIND_MNSTR_FIGHT;
-	strncpy( mbr->act.dflt_msg_mnstr,
+	str_nz_cpy( mbr->act.dflt_msg_mnstr,
 			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_LEN );
 	clr_chr_trgt_act( mbr, TRUE );
 	mbr->pre_act = mbr->act;
@@ -2454,15 +2457,15 @@ char	*get_race_str( race_t *race )
 	str_tmp[0] = '\0';
 	str_name[0] = '\0';
 
-	strncpy( str_main, get_race_str_main( race ), RACE_STR_MAX_LEN );
-	strncpy( str_sub, get_race_str_sub( race ), RACE_STR_MAX_LEN );
+	str_nz_cpy( str_main, get_race_str_main( race ), RACE_STR_MAX_LEN );
+	str_nz_cpy( str_sub, get_race_str_sub( race ), RACE_STR_MAX_LEN );
 
 	if( race->sub == SUB_RACE_NULL )
 		sprintf( str_tmp, MSG_RACE_STR_PUREBRED, str_main );
 	else
 		sprintf( str_tmp, MSG_RACE_STR_MIXED, str_main, str_sub );
 
-	strncpy( str_name, str_tmp, RACE_STR_MAX_LEN );
+	str_nz_cpy( str_name, str_tmp, RACE_STR_MAX_LEN );
 
 	return str_name;
 }
@@ -2633,7 +2636,7 @@ long	next_mbr( long mbr_n, long add )
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		mbr_n += add + MBR_MAX_N;
 		mbr_n %= MBR_MAX_N;
-		if( party.mbr[mbr_n]->stat != FLG_STAT_NOT_EXIST )
+		if( !chk_flg( party.mbr[mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 	}
 
@@ -2649,7 +2652,7 @@ long	next_ls_mbr( long ls_mbr_n, long add )
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		ls_mbr_n += add + LS_MBR_MAX_N;
 		ls_mbr_n %= LS_MBR_MAX_N;
-		if( ls_mbr[ls_mbr_n]->stat != FLG_STAT_NOT_EXIST )
+		if( !chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 	}
 
@@ -2712,24 +2715,47 @@ bool_t	cmp_class( class_t *org, class_t *dst )
 
 /**/
 
-void	arrange_class( long class_n )
+void	arrange_class( long class_n, long d )
 {
 	mbr_t	**ls_mbr = get_ls_mbr();
 	class_t	*p = get_class_tab();
 	class_t	tmp;
-	long	n;
+	long	n, tail;
 	long	i;
 
+	tail = 0;
+
 	tmp = p[class_n];
-	for( n = class_n - 1; n >= 0; n-- )
-		p[n + 1] = p[n];
-	p[0] = tmp;
+	if( d <= -1 ){
+		for( n = class_n - 1; n >= 0; n-- ){
+			p[n + 1] = p[n];
+		}
+
+		p[0] = tmp;
+	} else {
+		for( n = class_n + 1; n < CLASS_MAX_N; n++ ){
+			if( p[n].n_name == N_MSG_NULL )
+				break;
+
+			p[n - 1] = p[n];
+		}
+
+		p[n - 1] = tmp;
+		tail = n - 1;
+	}
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
-		if( ls_mbr[i]->class_n < class_n )
-			ls_mbr[i]->class_n++;
-		else if( ls_mbr[i]->class_n == class_n )
-			ls_mbr[i]->class_n = 0;
+		if( d <= -1 ){
+			if( ls_mbr[i]->class_n == class_n )
+				ls_mbr[i]->class_n = 0;
+			else if( ls_mbr[i]->class_n < class_n )
+				ls_mbr[i]->class_n++;
+		} else {
+			if( ls_mbr[i]->class_n == class_n )
+				ls_mbr[i]->class_n = tail;
+			else if( ls_mbr[i]->class_n > class_n )
+				ls_mbr[i]->class_n--;
+		}
 	}
 }
 
