@@ -96,11 +96,12 @@ void	chk_finish_request_exterminate(
 	request_kind_t req_kind,
 	bool_t flg_dec_add
 );
-bool_t	chk_finish_request_revenge( request_t *req );
+bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr );
 bool_t	chk_finish_request_wanted_criminal( request_t *req );
 void	close_all_request( chr_kind_t chr_kind );
 bool_t	close_request( request_t *req, chr_kind_t chr_kind );
-void	not_join_client( request_t *req );
+void	not_join_all_client( request_t *req, bool_t flg_success );
+void	not_join_client( request_t *req, pet_t *npc, bool_t flg_success );
 void	put_request_all_obj( void );
 void	put_request_rare_goods( chr_t *chr );
 void	put_request_item( void );
