@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.87 2006/01/29 12:18:55 bowkenken Exp $
+* $Id: request.c,v 1.90 2006/08/10 21:33:19 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -44,6 +44,9 @@
 # define	FLG_DEBUG_REQUEST	0
 #endif
 
+/* Υޥ */
+#define	BAR_MASTER_SEX	MALE
+
 /* Υ˥塼ꥹȤΥڡιܿ */
 #define	MENU_REQUEST_N_PER_PAGE	10
 
@@ -685,7 +688,7 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	if( npc == NULL )
 		return FALSE;
 
-	strncpy( npc->name, name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( npc->name, name, CHR_NAME_MAX_LEN );
 	npc->sex.org = sex;
 	npc->sex.cur = sex;
 	npc->work.request = req;
@@ -1039,7 +1042,7 @@ bool_t	chk_request_limit_client( request_t *req )
 			mnstr = NULL;
 		}
 		if( mnstr != NULL ){
-			strncpy( mnstr->name, npc->name, CHR_NAME_MAX_LEN );
+			str_nz_cpy( mnstr->name, npc->name, CHR_NAME_MAX_LEN );
 			mnstr->sex.org = npc->sex.cur;
 			mnstr->sex.cur = mnstr->sex.org;
 		}
@@ -1174,14 +1177,14 @@ bool_t	set_request_msg( request_t *req )
 		sprintf( str_contract,
 				MSG_REQUEST_CONTRACT_FMT, name );
 	} else {
-		strncpy( str_contract,
+		str_nz_cpy( str_contract,
 				MSG_REQUEST_DO_NOT_CONTRACT,
 				REQUEST_MSG_MAX_LEN );
 	}
 	str_max_n_cat( buf, "\n", REQUEST_MSG_MAX_LEN );
 	str_max_n_cat( buf, str_contract, REQUEST_MSG_MAX_LEN );
 
-	strncpy( req->msg, buf, REQUEST_MSG_MAX_LEN );
+	str_nz_cpy( req->msg, buf, REQUEST_MSG_MAX_LEN );
 
 	return TRUE;
 }
@@ -1833,7 +1836,7 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 		case REQUEST_KIND_EXTERMINATE:
 			break;
 		case REQUEST_KIND_REVENGE:
-			chk_finish_request_revenge( req );
+			chk_finish_request_revenge( req, chr );
 			break;
 		case REQUEST_KIND_WANTED_CRIMINAL:
 			chk_finish_request_wanted_criminal( req );
@@ -1975,7 +1978,7 @@ void	chk_finish_request_exterminate(
 * return : ꤬?
 ***************************************************************/
 
-bool_t	chk_finish_request_revenge( request_t *req )
+bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr )
 {
 	pet_t	*npc;
 
@@ -1983,12 +1986,12 @@ bool_t	chk_finish_request_revenge( request_t *req )
 		return FALSE;
 	if( req->kind != REQUEST_KIND_REVENGE )
 		return FALSE;
+	if( is_pet( chr ) )
+		return FALSE;
 
 	npc = get_npc_request( req );
-	if( npc == NULL ){
-		free_request( req );
+	if( cmp_chr( npc, chr ) )
 		return FALSE;
-	}
 
 	print_words( npc->name, npc->sex.cur,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_FEMALE,
@@ -2088,18 +2091,18 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 		}
 	}
 
-	not_join_client( req );
+	not_join_all_client( req, TRUE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, MALE,
-			MSG_WORDS_REQUEST_CLOSE_1,
-			MSG_WORDS_REQUEST_CLOSE_1 );
+	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+			MSG_WORDS_REQUEST_CLOSE_1_FEMALE,
+			MSG_WORDS_REQUEST_CLOSE_1_MALE );
 
 	add_party_gold( req->prize );
 	exp_party( req->exp, FALSE, TRUE );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, MALE,
-			MSG_WORDS_REQUEST_CLOSE_2,
-			MSG_WORDS_REQUEST_CLOSE_2 );
+	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+			MSG_WORDS_REQUEST_CLOSE_2_FEMALE,
+			MSG_WORDS_REQUEST_CLOSE_2_MALE );
 
 	/* end */
 
@@ -2109,21 +2112,51 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 }
 
 /***************************************************************
-* ̤
+* طƤΰ̤
 * request_t *req : 
+* bool_t flg_success : ꤬?
 ***************************************************************/
 
-void	not_join_client( request_t *req )
+void	not_join_all_client( request_t *req, bool_t flg_success )
 {
+	long	i;
 	pet_t	*npc;
+	pet_t	**ls_npc = get_ls_pet();
 
 	if( req == NULL )
 		return;
 
-	npc = get_npc_request( req );
+	for( i = 0; i < LS_PET_MAX_N; i++ ){
+		npc = ls_npc[i];
+
+		if( npc == NULL )
+			continue;
+		if( chk_flg_or( npc->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+		if( npc->work.request != req )
+			continue;
+
+		not_join_client( req, npc, flg_success );
+	}
+}
+
+/***************************************************************
+* ̤
+* request_t *req : 
+* pet_t *npc : 
+* bool_t flg_success : ꤬?
+***************************************************************/
+
+void	not_join_client( request_t *req, pet_t *npc, bool_t flg_success )
+{
+	char	*msg_female, *msg_male;
+
 	if( npc == NULL )
 		return;
 
+	msg_female = NULL;
+	msg_male = NULL;
+
 	switch( req->kind ){
 	case REQUEST_KIND_NULL:
 	case REQUEST_KIND_RARE_GOODS:
@@ -2132,27 +2165,29 @@ void	not_join_client( request_t *req )
 		/* ưʪʤ */
 		break;	/* return ǤϤʤ */
 	case REQUEST_KIND_RESCUE:
-		print_words( npc->name, npc->sex.cur,
-				MSG_WORDS_REQUEST_RESCUE_FINISH_FEMALE,
-				MSG_WORDS_REQUEST_RESCUE_FINISH_MALE );
+		msg_female = MSG_WORDS_REQUEST_RESCUE_FINISH_FEMALE,
+		msg_male = MSG_WORDS_REQUEST_RESCUE_FINISH_MALE;
 		break;
 	case REQUEST_KIND_TOUR_GUIDE:
-		print_words( npc->name, npc->sex.cur,
-				MSG_WORDS_REQUEST_TOUR_GUIDE_FINISH_FEMALE,
-				MSG_WORDS_REQUEST_TOUR_GUIDE_FINISH_MALE );
+		msg_female = MSG_WORDS_REQUEST_TOUR_GUIDE_FINISH_FEMALE,
+		msg_male = MSG_WORDS_REQUEST_TOUR_GUIDE_FINISH_MALE;
 		break;
 	case REQUEST_KIND_EXTERMINATE:
 		return;
 	case REQUEST_KIND_REVENGE:
-		print_words( npc->name, npc->sex.cur,
-				MSG_WORDS_REQUEST_REVENGE_FINISH_FEMALE,
-				MSG_WORDS_REQUEST_REVENGE_FINISH_MALE );
+		msg_female = MSG_WORDS_REQUEST_REVENGE_FINISH_FEMALE,
+		msg_male = MSG_WORDS_REQUEST_REVENGE_FINISH_MALE;
 		break;
 	case REQUEST_KIND_WANTED_CRIMINAL:
 	case REQUEST_KIND_MAX_N:
 		return;
 	}
 
+	if( flg_success && (msg_female != NULL) && (msg_male != NULL) ){
+		print_words( npc->name, npc->sex.cur,
+				msg_female, msg_male );
+	}
+
 	print_msg( FLG_NULL, MSG_NOT_JOIN_CHR, npc->name );
 	npc->gold = 0;
 	remove_pet( npc );
@@ -2306,7 +2341,7 @@ void	put_request_mnstr( void )
 		} else {
 			p->attitude = ATTITUDE_ENEMY;
 		}
-		strncpy( p->name, name, CHR_NAME_MAX_LEN );
+		str_nz_cpy( p->name, name, CHR_NAME_MAX_LEN );
 		p->work.request = &(g_request[i]);
 		p->sex.org = sex;
 		p->sex.cur = sex;
@@ -2380,8 +2415,8 @@ char	*set_menu_request(
 	ls = ls_menu_request;
 	k = 0;
 
-	strncpy( ls[k].path, "/request", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/request", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2391,12 +2426,12 @@ char	*set_menu_request(
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/request/--", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/request/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_MENU_BAR_REQUEST, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_BAR_REQUEST, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -2415,12 +2450,12 @@ char	*set_menu_request(
 		set_request_heading( &(g_request[i]) );
 
 		sprintf( ls[k].path, "/request/%ld", i );
-		strncpy( ls[k].kind, "<OpenWinItem>",
+		str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + (n % MENU_REQUEST_N_PER_PAGE));
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		strncpy( ls[k].msg, g_request[i].heading, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, g_request[i].heading, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb;
 		ls[k].arg = &(g_request[i]);
 		ls[k].flg = FLG_NULL;
@@ -2428,9 +2463,9 @@ char	*set_menu_request(
 		n++;
 
 		if( ((n % MENU_REQUEST_N_PER_PAGE) == 0) && !flg_mbr ){
-			strncpy( ls[k].path, "/request/Refresh",
+			str_nz_cpy( ls[k].path, "/request/Refresh",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 			ls[k].accel_key = 'Z';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
@@ -2443,9 +2478,9 @@ char	*set_menu_request(
 		}
 
 		if( (n % MENU_REQUEST_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path, "/request/--",
+			str_nz_cpy( ls[k].path, "/request/--",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -2458,9 +2493,9 @@ char	*set_menu_request(
 		}
 	}
 	if( !flg_mbr ){
-		strncpy( ls[k].path, "/request/Refresh",
+		str_nz_cpy( ls[k].path, "/request/Refresh",
 				MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
@@ -2603,9 +2638,9 @@ bool_t	ask_contract_request( request_t *req )
 	if( ask != ASK_YES )
 		return FALSE;
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, MALE,
-			MSG_WORDS_REQUEST_CONTRACT,
-			MSG_WORDS_REQUEST_CONTRACT );
+	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+			MSG_WORDS_REQUEST_CONTRACT_FEMALE,
+			MSG_WORDS_REQUEST_CONTRACT_MALE );
 
 	return( chr_contract_request( req, CHR_KIND_MBR, -1, FEMALE ) );
 }
@@ -2639,9 +2674,11 @@ bool_t	ask_cancel_request( request_t *req )
 	}
 	sub_party_gold( penalty );
 
-	print_words( MSG_NPC_NAME_BAR_MASTER, MALE,
-			MSG_WORDS_REQUEST_CANCEL,
-			MSG_WORDS_REQUEST_CANCEL );
+	not_join_all_client( req, FALSE );
+
+	print_words( MSG_NPC_NAME_BAR_MASTER, BAR_MASTER_SEX,
+			MSG_WORDS_REQUEST_CANCEL_FEMALE,
+			MSG_WORDS_REQUEST_CANCEL_MALE );
 
 	req->flg_contract = FALSE;
 	req->flg_contract_mbr = FALSE;
