@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: rumor-tab.h,v 1.4 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: rumor-tab.h,v 1.5 2006/01/27 05:07:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	RUMOR_TAB_H
@@ -60,6 +60,21 @@ rumor_tab_t	rumor_tab[] = {
 		N_MSG_RUMOR_003_MALE,
 		TRUE, FALSE,
 	},
+	{
+		N_MSG_RUMOR_004_FEMALE,
+		N_MSG_RUMOR_004_MALE,
+		TRUE, FALSE,
+	},
+	{
+		N_MSG_RUMOR_005_FEMALE,
+		N_MSG_RUMOR_005_MALE,
+		TRUE, FALSE,
+	},
+	{
+		N_MSG_RUMOR_006_FEMALE,
+		N_MSG_RUMOR_006_MALE,
+		TRUE, FALSE,
+	},
 	{
 		N_MSG_NULL,
 		N_MSG_NULL,
