@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.148 2006/02/17 04:45:36 bowkenken Exp $
+* $Id: spell.c,v 1.149 2006/08/12 04:22:56 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -227,6 +227,7 @@ void	init_spell_nin( void )
 
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 {
+	static mbr_t	*pre_sel_mbr = NULL;
 	pos_t	*crsr;
 	menu_t	*ls;
 	unsigned char	key;
@@ -236,8 +237,18 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 
 	crsr = get_crsr();
 	g_sel_mbr = get_mbr( crsr->x, crsr->y );
+	if( g_sel_mbr == NULL ){
+		char	*str;
+
+		g_sel_mbr = pre_sel_mbr;
+
+		str = exec_menu_sel_mbr( &g_sel_mbr, NULL, FALSE, FALSE );
+		if( str != NULL )
+			return STR_MENU_ERR;
+	}
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
+	pre_sel_mbr = g_sel_mbr;
 
 	if( chk_flg_or( g_sel_mbr->stat,
 			FLG_STAT_NOT_EXIST
