@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.90 2006/02/15 01:24:22 bowkenken Exp $
+* $Id: tmenu.c,v 1.99 2006/08/10 21:33:19 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -33,6 +33,9 @@
 
 /**/
 
+/* ƥŹä˼̤뤫? */
+#define	FLG_IDENTIFY_ITEM_SALE	FALSE
+
 #define	ARTICLE_MAX_N_PER_PAGE	10
 #define	ARTICLE_PAGE_MAX_N	MENU_MAX_PAGE
 #define	ARTICLE_MAX_N	\
@@ -447,8 +450,8 @@ char	*menu_order_sel_mbr( void )
 	mbr_n = 0;
 	k = 0;
 
-	strncpy( p[k].path, "/order", MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( p[k].path, "/order", MENU_PATH_MAX_LEN );
+	str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
 	p[k].msg[0] = '\0';
@@ -457,11 +460,11 @@ char	*menu_order_sel_mbr( void )
 	p[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( p[k].path, "/order/--", MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( p[k].path, "/order/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
-	strncpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_LEN );
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -482,7 +485,7 @@ char	*menu_order_sel_mbr( void )
 			dflt = &(p[k]);
 
 		sprintf( p[k].path, "/order/%ld", i );
-		strncpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = (char)('A' + i);
 		p[k].short_key[0] = '\0';
 		if( g_mbr_order[i] == NULL )
@@ -498,11 +501,11 @@ char	*menu_order_sel_mbr( void )
 		mbr_n++;
 	}
 
-	strncpy( p[k].path, "/order/chose", MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( p[k].path, "/order/chose", MENU_PATH_MAX_LEN );
+	str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = 'Z';
 	p[k].short_key[0] = '\0';
-	strncpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_LEN );
 	p[k].call_back = cb_menu_order_chose;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -657,8 +660,8 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 	dflt = NULL;
 	k = 0;
 
-	strncpy( ls[k].path, "/shop", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/shop", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].msg[0] = '\0';
@@ -685,9 +688,9 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 			continue;
 
 		if( key_n == 0 ){
-			strncpy( ls[k].path, "/shop/--",
+			str_nz_cpy( ls[k].path, "/shop/--",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<Title>",
+			str_nz_cpy( ls[k].kind, "<Title>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -715,7 +718,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 			dflt = &(ls[k]);
 
 		sprintf( ls[k].path, "/shop/%ld", key_n );
-		strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + key_n);
 		ls[k].short_key[0] = '\0';
 		ls[k].msg[0] = '\0';
@@ -734,9 +737,9 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 	}
 
 	if( (ls_art_n != (page * ARTICLE_MAX_N_PER_PAGE)) || page == 0 ){
-		strncpy( ls[k].path, "/shop/--",
+		str_nz_cpy( ls[k].path, "/shop/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( ls[k].kind, "<Title>",
+		str_nz_cpy( ls[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
@@ -782,11 +785,11 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* Data */
 
-	strncpy( ls[*k].path, "/shop/data", MENU_PATH_MAX_LEN );
-	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[*k].path, "/shop/data", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = 'T';
 	ls[*k].short_key[0] = '\0';
-	strncpy( ls[*k].msg, MSG_MENU_SHOP_DATA, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DATA, MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_shop_data;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -794,11 +797,11 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* Collect gold */
 
-	strncpy( ls[*k].path, "/shop/collect gold", MENU_PATH_MAX_LEN );
-	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[*k].path, "/shop/collect gold", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = 'U';
 	ls[*k].short_key[0] = '\0';
-	strncpy( ls[*k].msg, MSG_MENU_SHOP_COLLECT_GOLD,
+	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_COLLECT_GOLD,
 			MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_shop_collect_gold;
 	ls[*k].arg = NULL;
@@ -807,11 +810,11 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* Divide gold */
 
-	strncpy( ls[*k].path, "/shop/divide gold", MENU_PATH_MAX_LEN );
-	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[*k].path, "/shop/divide gold", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = 'V';
 	ls[*k].short_key[0] = '\0';
-	strncpy( ls[*k].msg, MSG_MENU_SHOP_DIVIDE_GOLD,
+	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DIVIDE_GOLD,
 			MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_shop_divide_gold;
 	ls[*k].arg = NULL;
@@ -820,11 +823,11 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* Give gold */
 
-	strncpy( ls[*k].path, "/shop/give gold", MENU_PATH_MAX_LEN );
-	strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[*k].path, "/shop/give gold", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = 'W';
 	ls[*k].short_key[0] = '\0';
-	strncpy( ls[*k].msg, MSG_MENU_SHOP_GIVE_GOLD,
+	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_GIVE_GOLD,
 			MENU_MSG_MAX_LEN );
 	ls[*k].call_back = cb_menu_shop_give_gold;
 	ls[*k].arg = NULL;
@@ -834,12 +837,12 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	if( !chk_shop_order( g_shop_n ) ){
 		/* Sale equip */
 		if( g_deal_kind != DEAL_KIND_SALE_EQUIP ){
-			strncpy( ls[*k].path, "/shop/sale equip",
+			str_nz_cpy( ls[*k].path, "/shop/sale equip",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 			ls[*k].accel_key = 'X';
 			ls[*k].short_key[0] = '\0';
-			strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
+			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
 					MENU_MSG_MAX_LEN );
 			ls[*k].call_back = cb_menu_shop_sale_equip;
 			ls[*k].arg = NULL;
@@ -849,12 +852,12 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 		/* Sale item */
 		if( g_deal_kind != DEAL_KIND_SALE_ITEM ){
-			strncpy( ls[*k].path, "/shop/sale item",
+			str_nz_cpy( ls[*k].path, "/shop/sale item",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 			ls[*k].accel_key = 'Y';
 			ls[*k].short_key[0] = '\0';
-			strncpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
+			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
 					MENU_MSG_MAX_LEN );
 			ls[*k].call_back = cb_menu_shop_sale_item;
 			ls[*k].arg = NULL;
@@ -864,11 +867,11 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 		/* Buy */
 		if( g_deal_kind != DEAL_KIND_BUY ){
-			strncpy( ls[*k].path, "/shop/buy", MENU_PATH_MAX_LEN );
-			strncpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[*k].path, "/shop/buy", MENU_PATH_MAX_LEN );
+			str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 			ls[*k].accel_key = 'Z';
 			ls[*k].short_key[0] = '\0';
-			strncpy( ls[*k].msg, MSG_MENU_SHOP_BUY,
+			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_BUY,
 					MENU_MSG_MAX_LEN );
 			ls[*k].call_back = cb_menu_shop_buy;
 			ls[*k].arg = NULL;
@@ -879,8 +882,8 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 
 	/* <PageSeparator> */
 
-	strncpy( ls[*k].path, "/shop/--", MENU_PATH_MAX_LEN );
-	strncpy( ls[*k].kind, "<PageSeparator>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[*k].path, "/shop/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[*k].kind, "<PageSeparator>", MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = '\0';
 	ls[*k].short_key[0] = '\0';
 	ls[*k].msg[0] = '\0';
@@ -979,6 +982,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 {
 	item_t	*art;
 	gold_t	price;
+	long	n, deal_n;
 
 	art = (item_t *)((*pp)->arg);
 	g_sel_art = art;
@@ -997,21 +1001,28 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 		}
 	}
 
+	n = art->n;
+
 	if( g_deal_kind == DEAL_KIND_BUY ){
-		if( !menu_shop_buy( g_shop_n, g_sel_mbr, art ) )
+		deal_n = menu_shop_buy( g_shop_n, g_sel_mbr, art );
+		if( deal_n <= 0 )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, -price );
+		add_chr_gold( g_sel_mbr, -(price * deal_n / n) );
+
 	} else if( g_deal_kind == DEAL_KIND_SALE_ITEM ){
-		if( !menu_shop_sale_item( g_shop_n, g_sel_mbr, art ) )
+		deal_n = menu_shop_sale_item( g_shop_n, g_sel_mbr, art );
+		if( deal_n <= 0 )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, +price );
+		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
+
 	} else if( g_deal_kind == DEAL_KIND_SALE_EQUIP ){
-		if( !menu_shop_sale_equip( g_shop_n, g_sel_mbr, art ) )
+		deal_n = menu_shop_sale_equip( g_shop_n, g_sel_mbr, art );
+		if( deal_n <= 0 )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, +price );
+		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
 	}
 
 	return "/shop";
@@ -1046,20 +1057,21 @@ char	*cb_menu_shop_sale_equip( menu_t **pp, menu_t **dflt )
 
 /**/
 
-bool_t	menu_shop_buy(
+long	menu_shop_buy(
 	shop_n_t g_shop_n, mbr_t *g_sel_mbr, item_t *item
 )
 {
 	ask_t	ask;
 	item_t	*tmp;
 	gold_t	price;
+	long	n;
 
 	price = get_price( g_shop_n, item, DEAL_KIND_BUY );
 
 	/* ̾ɽ */
 	print_msg( FLG_NULL, MSG_MENU_BUY, item->name );
 	if( !chk_pay( g_sel_mbr, price ) )
-		return FALSE;
+		return 0;
 
 	/* 㤦ǧ */
 	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, TRUE );
@@ -1069,17 +1081,19 @@ bool_t	menu_shop_buy(
 	case ASK_NO:
 	case ASK_CANCEL:
 	case ASK_ERR:
-		return FALSE;
+		return 0;
 	}
 
+	n = item->n;
+
 	tmp = alloc_item();
 	if( tmp == NULL )
-		return FALSE;
+		return 0;
 	copy_item( tmp, item );
 	tmp->stock = 1;
 
 	if( !give_mbr_item( g_sel_mbr, tmp, FALSE ) )
-		return FALSE;
+		return 0;
 
 	item->stock--;
 	if( item->stock <= 0 )
@@ -1088,50 +1102,59 @@ bool_t	menu_shop_buy(
 	print_msg( FLG_MSG_NO_MORE,
 			MSG_MENU_REACHED_BUY, item->name );
 
-	return TRUE;
+	return n;
 }
 
 /**/
 
-bool_t	menu_shop_sale_item(
+long	menu_shop_sale_item(
 	shop_n_t shop_n, mbr_t *mbr, item_t *item
 )
 {
-	return menu_shop_sale( shop_n, mbr, item, DEAL_KIND_SALE_ITEM );
+	return menu_shop_sale( shop_n, mbr, item,
+			DEAL_KIND_SALE_ITEM, FALSE );
 }
 
 /**/
 
-bool_t	menu_shop_sale_equip(
+long	menu_shop_sale_equip(
 	shop_n_t shop_n, mbr_t *mbr, item_t *item
 )
 {
-	return menu_shop_sale( shop_n, mbr, item, DEAL_KIND_SALE_EQUIP );
+	return menu_shop_sale( shop_n, mbr, item,
+			DEAL_KIND_SALE_EQUIP, FALSE );
 }
 
 /**/
 
-bool_t	menu_shop_sale(
+long	menu_shop_sale(
 	shop_n_t shop_n, mbr_t *mbr, item_t *item,
-	deal_kind_t deal_kind
+	deal_kind_t deal_kind, bool_t flg_auto_sale
 )
 {
 	ask_t	ask;
 	item_t	*tmp;
 	item_t	*asgn;
+	long	n;
 
-	/* ̾ɽ */
-	print_msg( FLG_NULL, MSG_MENU_SALE, item->name );
+	n = 0;
 
-	/* 뤫ǧ */
-	ask = exec_menu_ask( MSG_TTL_MENU_SALE, ASK_NO, TRUE );
-	switch( ask ){
-	case ASK_YES:
-		break;
-	case ASK_NO:
-	case ASK_CANCEL:
-	case ASK_ERR:
-		return FALSE;
+	if( !flg_auto_sale ){
+		/* ̾ɽ */
+
+		print_msg( FLG_NULL, MSG_MENU_SALE, item->name );
+
+		/* 뤫ǧ */
+
+		ask = exec_menu_ask( MSG_TTL_MENU_SALE, ASK_NO, TRUE );
+		switch( ask ){
+		case ASK_YES:
+			break;
+		case ASK_NO:
+		case ASK_CANCEL:
+		case ASK_ERR:
+			return 0;
+		}
 	}
 
 	lost_trgt( item );
@@ -1144,7 +1167,7 @@ bool_t	menu_shop_sale(
 	case SHOP_N_RESTAURANT:
 	case SHOP_N_TEAROOM:
 	case SHOP_N_TOBACCO:
-		return FALSE;
+		return 0;
 	case SHOP_N_TEMPLE:
 		asgn = get_shop_temple_item_asgn();
 		break;
@@ -1169,22 +1192,28 @@ bool_t	menu_shop_sale(
 			MSG_MENU_REACHED_SALE, item->name );
 
 	if( (asgn == NULL) || chk_flg( item->flg, FLG_ITEM_CURSED ) ){
-		if( chk_package_item( item ) ){
+		if( flg_auto_sale || chk_package_item( item ) ){
+			n = item->n;
 			del_item( item );
 		} else {
+			n = 1;
 			inc_item( item, -1 );
 		}
 	} else {
 		tmp = alloc_item();
 		if( tmp == NULL )
-			return FALSE;
+			return 0;
 		copy_item( tmp, item );
 		tmp->stock = 1;
 
-		if( chk_package_item( item ) ){
+		if( flg_auto_sale || chk_package_item( item ) ){
+			n = item->n;
+
 			ins_ls_item( asgn, tmp );
 			inc_item( item, -item->n );
 		} else {
+			n = 1;
+
 			tmp->n = 1;
 			inc_item( tmp, -(tmp->n - 1) );
 
@@ -1192,10 +1221,12 @@ bool_t	menu_shop_sale(
 			inc_item( item, -1 );
 		}
 
+#if	FLG_IDENTIFY_ITEM_SALE
 		identify_item( tmp );
+#endif
 	}
 
-	return TRUE;
+	return n;
 }
 
 /**/
@@ -1431,6 +1462,23 @@ bool_t	chk_deal_article(
 
 /**/
 
+shop_n_t	get_shop_deal_article( item_t *art, deal_kind_t deal_kind )
+{
+	long	i;
+
+	for( i = 0; i < SHOP_N_MAX_N; i++ ){
+		shop_n_t	shop_n;
+
+		shop_n = (shop_n_t)i;
+		if( chk_deal_article( art, shop_n, deal_kind ) )
+			return shop_n;
+	}
+
+	return SHOP_N_NULL;
+}
+
+/**/
+
 char	*menu_bar( void )
 {
 	g_sel_ls_mbr = get_ls_mbr()[0];
@@ -1461,9 +1509,9 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 	p = ls_menu_bar_form;
 
 	k = 0;
-	strncpy( p[k].path, "/bar form",
+	str_nz_cpy( p[k].path, "/bar form",
 			MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Branch>",
+	str_nz_cpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
@@ -1477,13 +1525,13 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 
-		strncpy( p[k].path, "/bar form/--",
+		str_nz_cpy( p[k].path, "/bar form/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( p[k].kind, "<Title>",
+		str_nz_cpy( p[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_TTL_MENU_BAR_FORM,
+		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_FORM,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
@@ -1500,11 +1548,11 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 			}
 
 			sprintf( p[k].path, "/bar form/%ld", ls_mbr_n );
-			strncpy( p[k].kind, "<CheckItem>",
+			str_nz_cpy( p[k].kind, "<CheckItem>",
 					MENU_KIND_MAX_LEN );
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
-			strncpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
+			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
 					MENU_MSG_MAX_LEN );
 			p[k].call_back = cb_menu_bar_form_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
@@ -1514,9 +1562,9 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 			ls_mbr_n++;
 		}
 
-		strncpy( p[k].path, "/bar form/--",
+		str_nz_cpy( p[k].path, "/bar form/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( p[k].kind, "<PageSeparator>",
+		str_nz_cpy( p[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
@@ -1579,7 +1627,7 @@ char	*cb_menu_bar_form_sub( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	strncpy( p->msg, g_sel_ls_mbr->name, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p->msg, g_sel_ls_mbr->name, MENU_MSG_MAX_LEN );
 
 	return NULL;
 }
@@ -1632,9 +1680,9 @@ char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 
 	k = 0;
-	strncpy( p[k].path, "/join",
+	str_nz_cpy( p[k].path, "/join",
 			MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Branch>",
+	str_nz_cpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
@@ -1647,7 +1695,7 @@ char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt )
 	n = 0;
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		sprintf( p[k].path, "/join/%ld", i );
-		strncpy( p[k].kind, "<Item>",
+		str_nz_cpy( p[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = (char)('A' + i);
 		p[k].short_key[0] = '\0';
@@ -1769,9 +1817,9 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 	p = ls_menu_bar_sel_mbr;
 
 	k = 0;
-	strncpy( p[k].path, "/edit member",
+	str_nz_cpy( p[k].path, "/edit member",
 			MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Branch>",
+	str_nz_cpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
@@ -1785,13 +1833,13 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 
-		strncpy( p[k].path, "/edit member/--",
+		str_nz_cpy( p[k].path, "/edit member/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( p[k].kind, "<Title>",
+		str_nz_cpy( p[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_TTL_MENU_BAR_EDIT_MBR,
+		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_EDIT_MBR,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
@@ -1809,11 +1857,11 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 
 			sprintf( p[k].path, "/edit member/%ld",
 					ls_mbr_n );
-			strncpy( p[k].kind, "<Branch>",
+			str_nz_cpy( p[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
-			strncpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
+			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
 					MENU_MSG_MAX_LEN );
 			p[k].call_back = cb_menu_bar_edit_mbr_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
@@ -1823,9 +1871,9 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 			ls_mbr_n++;
 		}
 
-		strncpy( p[k].path, "/edit member/--",
+		str_nz_cpy( p[k].path, "/edit member/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( p[k].kind, "<PageSeparator>",
+		str_nz_cpy( p[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
@@ -1908,7 +1956,21 @@ char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_bar_arrange( menu_t **pp, menu_t **dflt )
+char	*cb_menu_bar_arrange_top( menu_t **pp, menu_t **dflt )
+{
+	return cb_menu_bar_arrange( -1 );
+}
+
+/**/
+
+char	*cb_menu_bar_arrange_bottom( menu_t **pp, menu_t **dflt )
+{
+	return cb_menu_bar_arrange( +1 );
+}
+
+/**/
+
+char	*cb_menu_bar_arrange( long d )
 {
 	long	trgt_ls_mbr_n;
 	mbr_t	**ls_mbr, *tmp_mbr;
@@ -1921,14 +1983,32 @@ char	*cb_menu_bar_arrange( menu_t **pp, menu_t **dflt )
 	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
 
 	tmp_mbr = g_sel_ls_mbr;
-	for( i = trgt_ls_mbr_n - 1; i >= 0; i-- ){
-		ls_mbr[i + 1] = ls_mbr[i];
-		ls_mbr[i + 1]->ls_mbr_n++;
-	}
-	ls_mbr[0] = tmp_mbr;
-	ls_mbr[0]->ls_mbr_n = 0;
+	if( d <= -1 ){
+		for( i = trgt_ls_mbr_n - 1; i >= 0; i-- ){
+			ls_mbr[i + 1] = ls_mbr[i];
+			ls_mbr[i + 1]->ls_mbr_n++;
+		}
 
-	g_sel_ls_mbr = ls_mbr[0];
+		ls_mbr[0] = tmp_mbr;
+		ls_mbr[0]->ls_mbr_n = 0;
+
+		g_sel_ls_mbr = ls_mbr[0];
+	} else {
+		for( i = trgt_ls_mbr_n + 1; i < LS_MBR_MAX_N; i++ ){
+			if( chk_flg( ls_mbr[i]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+
+			ls_mbr[i - 1] = ls_mbr[i];
+			ls_mbr[i - 1]->ls_mbr_n--;
+		}
+
+		ls_mbr[i - 1] = tmp_mbr;
+		ls_mbr[i - 1]->ls_mbr_n = i - 1;
+
+		g_sel_ls_mbr = ls_mbr[i - 1];
+	}
 
 	return "/bar/form/edit member/edit member";
 }
@@ -1961,7 +2041,7 @@ bool_t	exec_menu_new_mbr( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	strncpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[n], MSG_MENU_NEW_MBR,
 			'@', race, MALE, 0, n );
 
@@ -2002,9 +2082,9 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 	p = ls_menu_bar_sel_mbr;
 
 	k = 0;
-	strncpy( p[k].path, "/bar remove member",
+	str_nz_cpy( p[k].path, "/bar remove member",
 			MENU_PATH_MAX_LEN );
-	strncpy( p[k].kind, "<Branch>",
+	str_nz_cpy( p[k].kind, "<Branch>",
 			MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
@@ -2018,13 +2098,13 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 
-		strncpy( p[k].path, "/bar remove member/--",
+		str_nz_cpy( p[k].path, "/bar remove member/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( p[k].kind, "<Title>",
+		str_nz_cpy( p[k].kind, "<Title>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
-		strncpy( p[k].msg, MSG_TTL_MENU_BAR_REMOVE_MBR,
+		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_REMOVE_MBR,
 				MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
@@ -2042,11 +2122,11 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 
 			sprintf( p[k].path, "/bar remove member/%ld",
 					ls_mbr_n );
-			strncpy( p[k].kind, "<OpenWinItem>",
+			str_nz_cpy( p[k].kind, "<OpenWinItem>",
 					MENU_KIND_MAX_LEN );
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
-			strncpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
+			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
 					MENU_MSG_MAX_LEN );
 			p[k].call_back = cb_menu_bar_remove_mbr_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
@@ -2056,9 +2136,9 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 			ls_mbr_n++;
 		}
 
-		strncpy( p[k].path, "/bar remove member/--",
+		str_nz_cpy( p[k].path, "/bar remove member/--",
 				MENU_PATH_MAX_LEN );
-		strncpy( p[k].kind, "<PageSeparator>",
+		str_nz_cpy( p[k].kind, "<PageSeparator>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
@@ -2182,9 +2262,18 @@ char	*menu_edit_class( long n )
 
 /**/
 
-char	*cb_menu_bar_arrange_class( menu_t **pp, menu_t **dflt )
+char	*cb_menu_bar_arrange_top_class( menu_t **pp, menu_t **dflt )
 {
-	arrange_class( g_sel_class_n );
+	arrange_class( g_sel_class_n, -1 );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_bar_arrange_bottom_class( menu_t **pp, menu_t **dflt )
+{
+	arrange_class( g_sel_class_n, +1 );
 
 	return NULL;
 }
@@ -2208,7 +2297,7 @@ char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
-	strncpy( p[n].name, MSG_MENU_NEW_CLASS, CLASS_NAME_MAX_LEN );
+	str_nz_cpy( p[n].name, MSG_MENU_NEW_CLASS, CLASS_NAME_MAX_LEN );
 
 	menu_new_class( n );
 
@@ -2599,6 +2688,7 @@ char	*cb_menu_inn_bath( menu_t **pp, menu_t **dflt )
 	mbr_t	*mbr;
 
 	str_goto = NULL;
+	mbr = NULL;
 
 	while( 1 ){
 		str_goto = exec_menu_sel_mbr(
@@ -2620,6 +2710,7 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 	menu_t	*ls, *p;
 	unsigned char	key;
 	bool_t	flg;
+	gold_t	gold;
 	long	i;
 
 	if( g_sel_mbr == NULL )
@@ -2662,17 +2753,22 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 
 		tab = get_spell_tab( kind );
 		if( tab == NULL ){
+			gold = 0;
 			sprintf( ls[i].msg, MSG_FMT_MENU_MAGIC_GUILD,
 					"", 0, fmt_gold( 0 ) );
 		} else {
-			gold_t	gold;
-
 			gold = get_price_spell( kind );
 			sprintf( ls[i].msg, MSG_FMT_MENU_MAGIC_GUILD,
 					tab->name, tab->lev,
 					fmt_gold( gold ) );
 		}
 
+		if( gold <= 0 ){
+			ls[i].flg |= FLG_MENU_HIDDEN;
+			ls[i].accel_key = '\0';
+			continue;
+		}
+
 		if( chk_chr_learned_spell( g_sel_mbr, kind ) ){
 			ls[i].flg |= FLG_MENU_HIDDEN;
 			ls[i].accel_key = '\0';
@@ -2737,6 +2833,15 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	if( tab == NULL )
 		return STR_MENU_ERR;
 
+	if( get_lev( g_sel_mbr, tab->abl ) < tab->lev ){
+		curs_attrset_chr( g_sel_mbr, -1, FALSE );
+		print_msg( FLG_NULL, MSG_CAN_NOT_LEARN_SPELL,
+				g_sel_mbr->name, tab->name );
+		curs_attrset_dflt();
+
+		return STR_MENU_CANCEL;
+	}
+
 	if( !chk_pay( g_sel_mbr, get_price_spell( kind ) ) )
 		return STR_MENU_CANCEL;
 
@@ -2805,8 +2910,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = LS_PET_MAX_N;
 
-	strncpy( ls[k].path, "/pet shop take", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop take", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2816,8 +2921,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/pet shop take/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop take/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2838,11 +2943,11 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 			continue;
 
 		sprintf( ls[k].path, "/pet shop take/%ld", (long)(i + 1) );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		strncpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_pet_shop_take_sel;
 		ls[k].arg = (void *)(ls_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -2852,10 +2957,10 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 		n++;
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path,
+			str_nz_cpy( ls[k].path,
 					"/pet shop take/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -2918,8 +3023,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = PET_MAX_N;
 
-	strncpy( ls[k].path, "/pet shop leave", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop leave", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2929,8 +3034,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/pet shop leave/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop leave/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -2951,11 +3056,11 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 			continue;
 
 		sprintf( ls[k].path, "/pet shop leave/%ld", (long)(i + 1) );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		strncpy( ls[k].msg, party_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, party_pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_pet_shop_leave_sel;
 		ls[k].arg = (void *)(party_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -2965,10 +3070,10 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 		n++;
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path,
+			str_nz_cpy( ls[k].path,
 					"/pet shop leave/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -3031,8 +3136,8 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = PET_MAX_N;
 
-	strncpy( ls[k].path, "/pet shop name", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop name", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3042,8 +3147,8 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/pet shop name/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop name/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3067,7 +3172,7 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 			mnstr_name = ls_pet[i]->mnstr_tab->name;
 
 		sprintf( ls[k].path, "/pet shop name/%ld", (long)(i + 1) );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
@@ -3082,10 +3187,10 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 		n++;
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path,
+			str_nz_cpy( ls[k].path,
 					"/pet shop name/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -3151,8 +3256,8 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	n = 0;
 	max_n = LS_PET_MAX_N;
 
-	strncpy( ls[k].path, "/pet shop remove", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop remove", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3162,8 +3267,8 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/pet shop remove/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop remove/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3182,11 +3287,11 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 			continue;
 
 		sprintf( ls[k].path, "/pet shop remove/%ld", (long)(i + 1) );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		strncpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_pet_shop_remove_sel;
 		ls[k].arg = (void *)(ls_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -3196,10 +3301,10 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 		n++;
 
 		if( (n % PET_SHOP_PET_N_PER_PAGE) == 0 ){
-			strncpy( ls[k].path,
+			str_nz_cpy( ls[k].path,
 					"/pet shop remove/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -3279,8 +3384,8 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	key = 'A';
 	max_n = PET_SHOP_PET_MAX_N;
 
-	strncpy( ls[k].path, "/pet shop buy", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop buy", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3290,8 +3395,8 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/pet shop buy/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop buy/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3309,10 +3414,10 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 			break;
 
 		if( (i != 0) && ((i % PET_SHOP_PET_N_PER_PAGE) == 0) ){
-			strncpy( ls[k].path,
+			str_nz_cpy( ls[k].path,
 					"/pet shop buy/page separator",
 					MENU_PATH_MAX_LEN );
-			strncpy( ls[k].kind, "<PageSeparator>",
+			str_nz_cpy( ls[k].kind, "<PageSeparator>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
@@ -3327,7 +3432,7 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 		}
 
 		sprintf( ls[k].path, "/pet shop buy/%ld", (long)(i + 1) );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
@@ -3408,20 +3513,27 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_town_init( menu_t **pp, menu_t **dflt )
+{
+	set_menu_dflt_main( *pp );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls;
 	long	k;
 	long	i;
 
-	set_menu_dflt_main( *pp );
-
 	*dflt = NULL;
 	ls = ls_menu_navi;
 	k = 0;
 
-	strncpy( ls[k].path, "/navi", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/navi", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
@@ -3431,19 +3543,19 @@ char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/navi/title", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/navi/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	strncpy( ls[k].msg, MSG_TTL_MENU_NAVI, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_NAVI, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	strncpy( ls[k].path, "/navi/stairs", MENU_PATH_MAX_LEN );
-	strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/navi/stairs", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = 'Z';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NAVI_PARTY_STAIRS;
@@ -3461,11 +3573,11 @@ char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 		mnr = get_shop_mnr_face( n );
 
 		sprintf( ls[k].path, "/navi/%c", (char)mnr );
-		strncpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = toupper( mnr );
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		strncpy( ls[k].msg, get_shop_name( n ), MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, get_shop_name( n ), MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb_menu_navi;
 		ls[k].arg = (void *)n;
 		ls[k].flg = FLG_NULL;
@@ -3503,3 +3615,194 @@ char	*cb_menu_navi_stairs( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_auto_sale( menu_t **pp, menu_t **dflt )
+{
+	menu_t	*ls;
+	char	*str_goto;
+
+	ls = ls_menu_auto_sale;
+	str_goto = NULL;
+	g_sel_mbr = NULL;
+
+	while( 1 ){
+		str_goto = exec_menu_sel_mbr(
+				&g_sel_mbr, MSG_TTL_MENU_AUTO_SALE_SEL_MBR,
+				TRUE, FALSE );
+		if( str_goto != NULL )
+			break;
+
+		while( 1 ){
+			if( !set_menu_auto_sale( ls, g_sel_mbr ) )
+				return STR_MENU_ERR;
+
+			str_goto = exec_menu( ls, NULL, NULL );
+			if( str_goto == NULL )
+				continue;
+			if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
+				break;
+
+			return str_goto;
+		}
+	}
+
+	if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
+		return NULL;
+
+	return str_goto;
+}
+
+/**/
+
+bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
+{
+	item_t	*art_head, *item;
+	long	len, max_len;
+	long	k;
+	long	i;
+
+	k = 0;
+
+	str_nz_cpy( ls[k].path, "/auto sale", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	str_nz_cpy( ls[k].path, "/auto sale/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	sprintf( ls[k].msg, MSG_TTL_MENU_AUTO_SALE, mbr->name );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	art_head = get_mbr_item_asgn( mbr );
+	if( art_head == NULL )
+		return FALSE;
+
+	max_len = 0;
+	item = art_head->next;
+	for( i = 1; i < LOOP_MAX_100; i++ ){
+		if( item == art_head )
+			break;
+
+		set_art_name( mbr, item, DEAL_KIND_SALE_ITEM );
+
+		len = str_len_std( item->art_name );
+		max_len = max_l( len, max_len );
+
+		item = item->next;
+	}
+
+	item = art_head->next;
+	for( i = 0; i < LOOP_MAX_100; i++ ){
+		shop_n_t	shop_n;
+		gold_t	price;
+
+		if( item == art_head )
+			break;
+
+		shop_n = get_shop_deal_article(
+				item, DEAL_KIND_SALE_ITEM );
+		price = get_price( shop_n, item, DEAL_KIND_SALE_ITEM );
+
+		sprintf( ls[k].path, "/auto sale/%ld", i );
+		str_nz_cpy( ls[k].kind, "<CheckItem>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = toupper( (char)('A' + i) );
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL,
+		sprintf( ls[k].msg,
+				MSG_FMT_ART_NAME,
+				max_len,
+				item->art_name,
+				fmt_gold( price ) );
+		ls[k].call_back = cb_menu_auto_sale_chk;
+		ls[k].arg = (void *)item;
+		ls[k].flg = FLG_MENU_CHK_OFF;
+		k++;
+
+		item = item->next;
+	}
+
+	str_nz_cpy( ls[k].path, "/auto sale/exec", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = 'Z';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_MENU_AUTO_SALE_EXEC;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = cb_menu_auto_sale_exec;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	ls[k].path[0] = '\0';
+
+	return TRUE;
+}
+
+/**/
+
+char	*cb_menu_auto_sale_chk( menu_t **pp, menu_t **dflt )
+{
+	set_key_buf_str( "2" );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
+{
+	ask_t	ask;
+	menu_t	*ls;
+	item_t	*item;
+	shop_n_t	shop_n;
+	gold_t	price;
+	long	i;
+
+	ask = exec_menu_ask( MSG_TTL_MENU_AUTO_SALE_ASK, ASK_NO, TRUE );
+	switch( ask ){
+	case ASK_YES:
+		break;
+	case ASK_NO:
+	case ASK_CANCEL:
+	case ASK_ERR:
+		return STR_MENU_CANCEL;
+	}
+
+	ls = ls_menu_auto_sale;
+
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( ls[i].path[0] == '\0' )
+			break;
+		if( ls[i].arg == NULL )
+			continue;
+		if( !chk_flg( ls[i].flg, FLG_MENU_CHK_ON ) )
+			continue;
+
+		item = (item_t *)(ls[i].arg);
+		shop_n = get_shop_deal_article( item, DEAL_KIND_SALE_ITEM );
+		price = get_price( shop_n, item, DEAL_KIND_SALE_ITEM );
+
+		menu_shop_sale( shop_n, g_sel_mbr, item,
+				DEAL_KIND_SALE_ITEM, TRUE );
+
+		if( price > 0 )
+			add_chr_gold( g_sel_mbr, +price );
+	}
+
+	add_turn( NAVI_ADD_TURN_N + SHOP_ADD_TURN_N );
+
+	return NULL;
+}
+
+/**/
+
