@@ -25,12 +25,15 @@ void	reset_shop_face_ls( void );
 bool_t	set_shop_face_ls( char mnr );
 bool_t	chk_shop_face_ls( void );
 bool_t	appear_party_town( void );
+bool_t	navi_party( shop_n_t shop_n );
+bool_t	navi_party_stairs();
 bool_t	open_door_shop( long n );
 bool_t	enter_shop( void );
 void	party_exit_shop( long dr_n );
 bool_t	chk_shop_open( shop_n_t shop_n, bool_t flg_print );
 bool_t	chk_package_item( item_t *item );
 void	stay_inn( bool_t flg_short_stay );
+void	take_bath( chr_t *chr );
 bool_t	set_art_name( mbr_t *mbr, item_t *art, deal_kind_t kind );
 bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq );
 bool_t	chk_pay( mbr_t *mbr, gold_t price );
