@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.117 2006/02/15 01:24:22 bowkenken Exp $
+* $Id: town.c,v 1.118 2006/02/24 14:39:37 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -37,9 +37,6 @@
 
 /**/
 
-#define	SHOP_ADD_TURN_N	(15 * TURN_PER_MINUTE)
-#define	NAVI_ADD_TURN_N	((MAP_MAX_X + MAP_MAX_Y) / 2)
-
 #define	OPEN_TURN_BAR	( 0 * TURN_PER_HOUR)
 #define	CLOSE_TURN_BAR	(24 * TURN_PER_HOUR)
 #define	OPEN_TURN_INN	( 0 * TURN_PER_HOUR)
