@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.54 2006/02/04 08:11:47 bowkenken Exp $
+* $Id: trap.c,v 1.55 2006/08/10 21:33:19 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -579,7 +579,7 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	}
 
 	g_dmy_chr.kind = CHR_KIND_NULL;
-	strncpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_LEN );
 	g_dmy_chr.x = trap->x;
 	g_dmy_chr.y = trap->y;
 	g_dmy_chr.trgt.kind = get_trgt_kind_from_chr( chr );
