@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,16 +25,25 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.h,v 1.23 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: trap.h,v 1.28 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TRAP_H
 #define	TRAP_H
 
+/***************************************************************
+* 
+***************************************************************/
+
 #include	"gmain.h"
 #include	"msg.h"
 
+/***************************************************************
+* ǥХåѥå
+***************************************************************/
+
 /* 1 ˤ櫤̤ˤĤ */
+
 #if	0
 # ifndef	D_TEST_TRAP
 #  define	D_TEST_TRAP
@@ -42,13 +51,14 @@
 #endif
 
 /* 1 ˤ櫤Ĥ */
+
 #if	0
 # ifndef	D_TEST_TRAP_KIND
 #  define	D_TEST_TRAP_KIND	TRAP_KIND_ARW
 # endif
 #endif
 
-#if	defined( DEBUG ) && defined( D_TEST_TRAP )
+#if	(!defined( NDEBUG )) && defined( DEBUG ) && defined( D_TEST_TRAP )
 # define	TRAP_AVE_N	512
 # define	TRAP_MAX_N	1024
 #else
@@ -56,37 +66,75 @@
 # define	TRAP_MAX_N	128
 #endif
 
-/* 櫤μ */
+/***************************************************************
+* 櫤μ
+***************************************************************/
 
 typedef enum {
 	TRAP_KIND_NULL,
+	/* ̲ */
 	TRAP_KIND_SLEEP,
+	/*  */
 	TRAP_KIND_ARW,
+	/* ǥĤ */
 	TRAP_KIND_POISON_DARTS,
+	/* Ƥ */
 	TRAP_KIND_BOMB,
+	/* ѡƥְִư */
 	TRAP_KIND_TELEPORT_PARTY,
+	/* ְִư */
 	TRAP_KIND_TELEPORT,
+	/*  */
 	TRAP_KIND_PIT,
+	/* 塼 */
 	TRAP_KIND_CHUTE,
+	/*  */
+	TRAP_KIND_SANCTUARY,
 	TRAP_KIND_MAX_N
 } trap_kind_t;
 
+/***************************************************************
+* 櫤Υǡơ֥
+***************************************************************/
+
 typedef struct {
+	/*  */
 	trap_kind_t	kind;
-	char	*name;
+	/* ̾ ID */
 	n_msg_t	name_n;
-	rate_t	rate;	/* иΨ */
+	/* ̾ */
+	char	*name;
+	/* иΨ */
+	rate_t	rate;
+	/* ޥʡʸ */
 	char	mnr;
-	long	min_lev, max_lev, sgn_lev;	/* и */
+	/* и */
+	long	min_lev, max_lev, sgn_lev;
+	/* åɽ뤫? */
+	bool_t	flg_draw_msg;
 } trap_tab_t;
 
+/***************************************************************
+* 櫤Υǡ
+***************************************************************/
+
 typedef struct trap_t {
+	/* 󥯡ݥ */
 	struct trap_t	*next, *prev;
+
+	/*  */
 	trap_kind_t	kind;
+	/* ɸ */
 	long	x, y;
+
+	/* 櫤Υ٥ */
 	long	lev;
-	long	difficulty;	/* 񤷤 */
+	/* 񤷤 */
+	long	difficulty;
+	/* Ĵ٤Ƥ뤫 */
 	bool_t	flg_chked;
+
+	/* ǡơ֥ */
 	trap_tab_t	*tab;
 } trap_t;
 
